@@ -14,8 +14,13 @@
 
 import os
 import sys
-from configparser import ConfigParser
-from datetime import datetime
+from datetime import datetime, timezone
+from pathlib import Path
+
+if sys.version_info < (3, 11):
+    import tomli as tomllib
+else:
+    import tomllib
 
 try:
     from sphinx_astropy.conf.v1 import *  # noqa: F403
@@ -24,11 +29,10 @@ except ImportError:
           'be installed')
     sys.exit(1)
 
-# Get configuration information from setup.cfg
-conf = ConfigParser()
-conf.read([os.path.join(os.path.dirname(__file__), '..', 'setup.cfg')])
-setup_cfg = dict(conf.items('metadata'))
-
+# Get configuration information from pyproject.toml
+with (Path(__file__).parents[1] / 'pyproject.toml').open('rb') as fh:
+    conf = tomllib.load(fh)
+    project_meta = conf['project']
 
 # -- General configuration ----------------------------------------------------
 # By default, highlight as Python 3.
@@ -46,10 +50,10 @@ del intersphinx_mapping['h5py']  # noqa: F405
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
-exclude_patterns.append('_templates')  # noqa: F405
 # Exclude template PSF block specification documentation
 exclude_patterns.append('psf_spec/*')  # noqa: F405
 
+
 plot_formats = ['png', 'hires.png', 'pdf', 'svg']
 
 # This is added to the end of RST files - a good place to put
@@ -61,15 +65,14 @@ rst_epilog = """
 # Turn off table of contents entries for functions and classes
 toc_object_entries = False
 
-
 # -- Project information ------------------------------------------------------
-project = setup_cfg['name']
-author = setup_cfg['author']
-copyright = f'2011-{datetime.utcnow().year}, {author}'
+project = project_meta['name']
+author = project_meta['authors'][0]['name']
+copyright = f'2011-{datetime.now(tz=timezone.utc).year}, {author}'
 
-# The version info for the project you're documenting, acts as replacement for
-# |version| and |release|, also used in various other places throughout the
-# built documents.
+# The version info for the project you're documenting, acts as
+# replacement for |version| and |release|, also used in various other
+# places throughout the built documents.
 __import__(project)
 package = sys.modules[project]
 
@@ -78,14 +81,13 @@ version = package.__version__.split('-', 1)[0]
 # The full version, including alpha/beta/rc tags.
 release = package.__version__
 
-
 # -- Options for HTML output --------------------------------------------------
 # The global astropy configuration uses a custom theme,
-# 'bootstrap-astropy', which is installed along with astropy. A different
-# theme can be used or the options for this theme can be modified by
-# overriding some of the variables set in the global configuration. The
-# variables set in the global configuration are listed below, commented
-# out.
+# 'bootstrap-astropy', which is installed along with astropy. A
+# different theme can be used or the options for this theme can be
+# modified by overriding some of the variables set in the global
+# configuration. The variables set in the global configuration are
+# listed below, commented out.
 
 # Add any paths that contain custom themes here, relative to this
 # directory.
@@ -112,8 +114,8 @@ html_theme_options = {
 # html_logo = ''
 
 # The name of an image file (within the static path) to use as favicon
-# of the docs. This file should be a Windows icon file (.ico) being 16x16
-# or 32x32 pixels large.
+# of the docs. This file should be a Windows icon file (.ico) being
+# 16x16 or 32x32 pixels large.
 html_favicon = os.path.join('_static', 'favicon.ico')
 
 # A "Last built" timestamp is inserted at every page bottom, using the
@@ -131,7 +133,6 @@ htmlhelp_basename = project + 'doc'
 html_static_path = ['_static']
 html_style = 'photutils.css'
 
-
 # -- Options for LaTeX output -------------------------------------------------
 # Grouping the document tree into LaTeX files. List of tuples (source
 # start file, target name, title, author, documentclass [howto/manual]).
@@ -139,19 +140,16 @@ latex_documents = [('index', project + '.tex', project + ' Documentation',
                     author, 'manual')]
 latex_logo = '_static/photutils_banner.pdf'
 
-
 # -- Options for manual page output -------------------------------------------
 # One entry per manual page. List of tuples (source start file, name,
 # description, authors, manual section).
 man_pages = [('index', project.lower(), project + ' Documentation',
               [author], 1)]
 
-
 # -- Resolving issue number to links in changelog -----------------------------
-github_project = setup_cfg['github_project']
+github_project = conf['tool']['build-sphinx']['github_project']
 github_issues_url = f'https://github.com/{github_project}/issues/'
 
-
 # -- Turn on nitpicky mode for sphinx (to warn about references not found) ----
 nitpicky = True
 nitpick_ignore = []
@@ -172,13 +170,12 @@ nitpick_ignore = []
 nitpick_filename = 'nitpick-exceptions.txt'
 if os.path.isfile(nitpick_filename):
     for line in open(nitpick_filename):
-        if line.strip() == "" or line.startswith("#"):
+        if line.strip() == '' or line.startswith('#'):
             continue
         dtype, target = line.split(None, 1)
         target = target.strip()
         nitpick_ignore.append((dtype, target))
 
-
 # -- Options for linkcheck output ---------------------------------------------
 linkcheck_retry = 5
 linkcheck_ignore = ['http://data.astropy.org',
