@@ -9,12 +9,13 @@ import math
 import astropy.units as u
 import numpy as np
 
-from .attributes import (ScalarAngle, PixelPositions, PositiveScalar,
-                         SkyCoordPositions, ScalarAngleOrPixel,
-                         ScalarAngleOrValue)
-from .core import PixelAperture, SkyAperture
-from .mask import ApertureMask
-from ..geometry import rectangular_overlap_grid
+from photutils.aperture.attributes import (PixelPositions, PositiveScalar,
+                                           PositiveScalarAngle, ScalarAngle,
+                                           ScalarAngleOrValue,
+                                           SkyCoordPositions)
+from photutils.aperture.core import PixelAperture, SkyAperture
+from photutils.aperture.mask import ApertureMask
+from photutils.geometry import rectangular_overlap_grid
 
 __all__ = ['RectangularMaskMixin', 'RectangularAperture',
            'RectangularAnnulus', 'SkyRectangularAperture',
@@ -62,7 +63,7 @@ class RectangularMaskMixin:
         subpixels : int, optional
             For the ``'subpixel'`` method, resample pixels by this
             factor in each dimension. That is, each pixel is divided
-            into ``subpixels ** 2`` subpixels. This keyword is ignored
+            into ``subpixels**2`` subpixels. This keyword is ignored
             unless ``method='subpixel'``.
 
         Returns
@@ -86,8 +87,7 @@ class RectangularMaskMixin:
             raise ValueError('Cannot determine the aperture radius.')
 
         masks = []
-        for bbox, edges in zip(np.atleast_1d(self.bbox),
-                               self._centered_edges):
+        for bbox, edges in zip(self._bbox, self._centered_edges):
             ny, nx = bbox.shape
             mask = rectangular_overlap_grid(edges[0], edges[1], edges[2],
                                             edges[3], nx, ny, w, h,
@@ -113,8 +113,8 @@ class RectangularMaskMixin:
         """
         Calculate half of the bounding box extents of an ellipse.
         """
-        half_width = width / 2.
-        half_height = height / 2.
+        half_width = width / 2.0
+        half_height = height / 2.0
         sin_theta = math.sin(theta)
         cos_theta = math.cos(theta)
         x_extent1 = abs((half_width * cos_theta) - (half_height * sin_theta))
@@ -134,8 +134,8 @@ class RectangularMaskMixin:
         Used for creating `~matplotlib.patches.Rectangle` patch for the
         aperture.
         """
-        half_width = width / 2.
-        half_height = height / 2.
+        half_width = width / 2.0
+        half_height = height / 2.0
         sin_theta = math.sin(theta)
         cos_theta = math.cos(theta)
         xshift = (half_height * sin_theta) - (half_width * cos_theta)
@@ -159,9 +159,6 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
 
             * single ``(x, y)`` pair as a tuple, list, or `~numpy.ndarray`
             * tuple, list, or `~numpy.ndarray` of ``(x, y)`` pairs
-            * `~astropy.units.Quantity` instance of ``(x, y)`` pairs in
-              pixel units (this is Deprecated and will be removed in a
-              future version)
 
     w : float
         The full width of the rectangle in pixels.  For ``theta=0`` the
@@ -188,14 +185,14 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
     >>> from photutils.aperture import RectangularAperture
 
     >>> theta = Angle(80, 'deg')
-    >>> aper = RectangularAperture([10., 20.], 5., 3.)
-    >>> aper = RectangularAperture((10., 20.), 5., 3., theta=theta)
+    >>> aper = RectangularAperture([10.0, 20.0], 5.0, 3.0)
+    >>> aper = RectangularAperture((10.0, 20.0), 5.0, 3.0, theta=theta)
 
-    >>> pos1 = (10., 20.)  # (x, y)
-    >>> pos2 = (30., 40.)
-    >>> pos3 = (50., 60.)
-    >>> aper = RectangularAperture([pos1, pos2, pos3], 5., 3.)
-    >>> aper = RectangularAperture((pos1, pos2, pos3), 5., 3., theta=theta)
+    >>> pos1 = (10.0, 20.0)  # (x, y)
+    >>> pos2 = (30.0, 40.0)
+    >>> pos3 = (50.0, 60.0)
+    >>> aper = RectangularAperture([pos1, pos2, pos3], 5.0, 3.0)
+    >>> aper = RectangularAperture((pos1, pos2, pos3), 5.0, 3.0, theta=theta)
     """
 
     _params = ('positions', 'w', 'h', 'theta')
@@ -206,7 +203,7 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
                                'angular Quantity or value in radians from '
                                'the positive x axis.')
 
-    def __init__(self, positions, w, h, theta=0.):
+    def __init__(self, positions, w, h, theta=0.0):
         self.positions = positions
         self.w = w
         self.h = h
@@ -250,10 +247,10 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
                                                   self.h, self._theta_radians)
 
         patches = []
-        theta_deg = self._theta_radians * 180. / np.pi
+        theta_deg = self._theta_radians * 180.0 / np.pi
         for xy_position in xy_positions:
             patches.append(mpatches.Rectangle(xy_position, self.w, self.h,
-                                              theta_deg, **patch_kwargs))
+                                              angle=theta_deg, **patch_kwargs))
 
         if self.isscalar:
             return patches[0]
@@ -300,9 +297,6 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
 
             * single ``(x, y)`` pair as a tuple, list, or `~numpy.ndarray`
             * tuple, list, or `~numpy.ndarray` of ``(x, y)`` pairs
-            * `~astropy.units.Quantity` instance of ``(x, y)`` pairs in
-              pixel units (this is Deprecated and will be removed in a
-              future version)
 
     w_in : float
         The inner full width of the rectangular annulus in pixels.  For
@@ -346,14 +340,14 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
     >>> from photutils.aperture import RectangularAnnulus
 
     >>> theta = Angle(80, 'deg')
-    >>> aper = RectangularAnnulus([10., 20.], 3., 8., 5.)
-    >>> aper = RectangularAnnulus((10., 20.), 3., 8., 5., theta=theta)
+    >>> aper = RectangularAnnulus([10.0, 20.0], 3.0, 8.0, 5.0)
+    >>> aper = RectangularAnnulus((10.0, 20.0), 3.0, 8.0, 5.0, theta=theta)
 
-    >>> pos1 = (10., 20.)  # (x, y)
-    >>> pos2 = (30., 40.)
-    >>> pos3 = (50., 60.)
-    >>> aper = RectangularAnnulus([pos1, pos2, pos3], 3., 8., 5.)
-    >>> aper = RectangularAnnulus((pos1, pos2, pos3), 3., 8., 5., theta=theta)
+    >>> pos1 = (10.0, 20.0)  # (x, y)
+    >>> pos2 = (30.0, 40.0)
+    >>> pos3 = (50.0, 60.0)
+    >>> aper = RectangularAnnulus([pos1, pos2, pos3], 3.0, 8.0, 5.0)
+    >>> aper = RectangularAnnulus((pos1, pos2, pos3), 3.0, 8.0, 5.0, theta=theta)
     """
 
     _params = ('positions', 'w_in', 'w_out', 'h_in', 'h_out', 'theta')
@@ -366,7 +360,7 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
                                'angular Quantity or value in radians from '
                                'the positive x axis.')
 
-    def __init__(self, positions, w_in, w_out, h_out, h_in=None, theta=0.):
+    def __init__(self, positions, w_in, w_out, h_out, h_in=None, theta=0.0):
         if not w_out > w_in:
             raise ValueError('"w_out" must be greater than "w_in"')
 
@@ -427,12 +421,12 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
                                                         self._theta_radians)
 
         patches = []
-        theta_deg = self._theta_radians * 180. / np.pi
+        theta_deg = self._theta_radians * 180.0 / np.pi
         for xy_in, xy_out in zip(inner_xy_positions, outer_xy_positions):
             patch_inner = mpatches.Rectangle(xy_in, self.w_in, self.h_in,
-                                             theta_deg)
+                                             angle=theta_deg)
             patch_outer = mpatches.Rectangle(xy_out, self.w_out, self.h_out,
-                                             theta_deg)
+                                             angle=theta_deg)
             path = self._make_annulus_path(patch_inner, patch_outer)
             patches.append(mpatches.PathPatch(path, **patch_kwargs))
 
@@ -480,14 +474,12 @@ class SkyRectangularAperture(SkyAperture):
         either scalar coordinates or an array of coordinates.
 
     w : scalar `~astropy.units.Quantity`
-        The full width of the rectangle in angular units. Pixel units
-        are now deprecated. For ``theta=0`` the width side is along the
-        North-South axis.
+        The full width of the rectangle in angular units. For
+        ``theta=0`` the width side is along the North-South axis.
 
     h :  scalar `~astropy.units.Quantity`
-        The full height of the rectangle in angular units. Pixel units
-        are now deprecated. For ``theta=0`` the height side is along the
-        East-West axis.
+        The full height of the rectangle in angular units. For
+        ``theta=0`` the height side is along the East-West axis.
 
     theta : scalar `~astropy.units.Quantity`, optional
         The position angle (in angular units) of the rectangle "width"
@@ -499,22 +491,18 @@ class SkyRectangularAperture(SkyAperture):
     >>> from astropy.coordinates import SkyCoord
     >>> import astropy.units as u
     >>> from photutils.aperture import SkyRectangularAperture
-    >>> positions = SkyCoord(ra=[10., 20.], dec=[30., 40.], unit='deg')
+    >>> positions = SkyCoord(ra=[10.0, 20.0], dec=[30.0, 40.0], unit='deg')
     >>> aper = SkyRectangularAperture(positions, 1.0*u.arcsec, 0.5*u.arcsec)
     """
 
     _params = ('positions', 'w', 'h', 'theta')
     positions = SkyCoordPositions('The center position(s) in sky coordinates.')
-    w = ScalarAngleOrPixel('The full width in angular units.')
-    h = ScalarAngleOrPixel('The full height in angular units.')
+    w = PositiveScalarAngle('The full width in angular units.')
+    h = PositiveScalarAngle('The full height in angular units.')
     theta = ScalarAngle('The position angle (in angular units) of the '
                         'rectangle "width" side.')
 
-    def __init__(self, positions, w, h, theta=0. * u.deg):
-        if w.unit.physical_type != h.unit.physical_type:
-            raise ValueError('"w" and "h" should either both be angles or '
-                             'in pixels')
-
+    def __init__(self, positions, w, h, theta=0.0 * u.deg):
         self.positions = positions
         self.w = w
         self.h = h
@@ -556,22 +544,21 @@ class SkyRectangularAnnulus(SkyAperture):
 
     w_in : scalar `~astropy.units.Quantity`
         The inner full width of the rectangular annulus in angular
-        units. Pixel units are now deprecated. For ``theta=0`` the width
-        side is along the North-South axis.
+        units. For ``theta=0`` the width side is along the North-South
+        axis.
 
     w_out : scalar `~astropy.units.Quantity`
         The outer full width of the rectangular annulus in angular
-        units. Pixel units are now deprecated. For ``theta=0`` the width
-        side is along the North-South axis.
+        units. For ``theta=0`` the width side is along the North-South
+        axis.
 
     h_out : scalar `~astropy.units.Quantity`
         The outer full height of the rectangular annulus in angular
-        units. Pixel units are now deprecated.
+        units.
 
     h_in : `None` or scalar `~astropy.units.Quantity`
         The outer full height of the rectangular annulus in angular
-        units. Pixel units are now deprecated. If `None`, then the inner
-        full height is calculated as:
+        units. If `None`, then the inner full height is calculated as:
 
             .. math:: h_{in} = h_{out}
                 \left(\frac{w_{in}}{w_{out}}\right)
@@ -588,28 +575,22 @@ class SkyRectangularAnnulus(SkyAperture):
     >>> from astropy.coordinates import SkyCoord
     >>> import astropy.units as u
     >>> from photutils.aperture import SkyRectangularAnnulus
-    >>> positions = SkyCoord(ra=[10., 20.], dec=[30., 40.], unit='deg')
+    >>> positions = SkyCoord(ra=[10.0, 20.0], dec=[30.0, 40.0], unit='deg')
     >>> aper = SkyRectangularAnnulus(positions, 3.0*u.arcsec, 8.0*u.arcsec,
     ...                              5.0*u.arcsec)
     """
 
     _params = ('positions', 'w_in', 'w_out', 'h_in', 'h_out', 'theta')
     positions = SkyCoordPositions('The center position(s) in sky coordinates.')
-    w_in = ScalarAngleOrPixel('The inner full width in angular units.')
-    w_out = ScalarAngleOrPixel('The outer full width in angular units.')
-    h_in = ScalarAngleOrPixel('The inner full height in angular units.')
-    h_out = ScalarAngleOrPixel('The outer full height in angular units.')
+    w_in = PositiveScalarAngle('The inner full width in angular units.')
+    w_out = PositiveScalarAngle('The outer full width in angular units.')
+    h_in = PositiveScalarAngle('The inner full height in angular units.')
+    h_out = PositiveScalarAngle('The outer full height in angular units.')
     theta = ScalarAngle('The position angle (in angular units) of the '
                         'rectangle "width" side.')
 
     def __init__(self, positions, w_in, w_out, h_out, h_in=None,
-                 theta=0. * u.deg):
-        if w_in.unit.physical_type != w_out.unit.physical_type:
-            raise ValueError('w_in and w_out should either both be angles or '
-                             'in pixels')
-        if w_out.unit.physical_type != h_out.unit.physical_type:
-            raise ValueError('w_out and h_out should either both be angles '
-                             'or in pixels')
+                 theta=0.0 * u.deg):
         if not w_out > w_in:
             raise ValueError('"w_out" must be greater than "w_in".')
 
@@ -621,9 +602,6 @@ class SkyRectangularAnnulus(SkyAperture):
         if h_in is None:
             h_in = self.w_in * self.h_out / self.w_out
         else:
-            if h_in.unit.physical_type != h_out.unit.physical_type:
-                raise ValueError('h_in and h_out should either both be '
-                                 'angles or in pixels')
             if not h_out > h_in:
                 raise ValueError('"h_out" must be greater than "h_in".')
         self.h_in = h_in
