@@ -12,13 +12,13 @@ from astropy.nddata import NDData
 from astropy.stats import SigmaClip
 from astropy.utils import lazyproperty
 from astropy.utils.exceptions import AstropyUserWarning
-from numpy.lib.index_tricks import index_exp
 
 from photutils.aperture import RectangularAperture
 from photutils.background.core import SExtractorBackground, StdBackgroundRMS
 from photutils.background.interpolators import BkgZoomInterpolator
 from photutils.utils import ShepardIDWInterpolator
 from photutils.utils._parameters import as_pair
+from photutils.utils._repr import make_repr
 from photutils.utils._stats import nanmedian
 
 __all__ = ['Background2D']
@@ -230,6 +230,19 @@ class Background2D:
 
         self._prepare_box_data()
 
+        self._params = ('data', 'box_size', 'mask', 'coverage_mask',
+                        'fill_value', 'exclude_percentile', 'filter_size',
+                        'filter_threshold', 'edge_method', 'sigma_clip',
+                        'bkg_estimator', 'bkgrms_estimator', 'interpolator')
+
+    def __repr__(self):
+        ellipsis = ('data', 'mask', 'coverage_mask')
+        return make_repr(self, self._params, ellipsis=ellipsis)
+
+    def __str__(self):
+        ellipsis = ('data', 'mask', 'coverage_mask')
+        return make_repr(self, self._params, ellipsis=ellipsis, long=True)
+
     def _validate_array(self, array, name, shape=True):
         if name in ('mask', 'coverage_mask') and array is np.ma.nomask:
             array = None
@@ -306,7 +319,7 @@ class Background2D:
                 self.nboxes = data.shape // self.box_size
             elif self.edge_method == 'crop':
                 crop_size = self.nboxes * self.box_size
-                crop_slc = index_exp[0:crop_size[0], 0:crop_size[1]]
+                crop_slc = np.index_exp[0:crop_size[0], 0:crop_size[1]]
                 data = self.data[crop_slc]
             else:
                 raise ValueError('edge_method must be "pad" or "crop"')
@@ -374,7 +387,7 @@ class Background2D:
 
     def _sigmaclip_boxes(self):
         with warnings.catch_warnings():
-            warnings.simplefilter("ignore", category=AstropyUserWarning)
+            warnings.simplefilter('ignore', category=AstropyUserWarning)
             if self.sigma_clip is not None:
                 self._box_data = self.sigma_clip(self._box_data, axis=1,
                                                  masked=False)
@@ -667,31 +680,30 @@ class Background2D:
             current `~matplotlib.axes.Axes` instance is used.
 
         marker : str, optional
-            The marker to use to mark the center of the boxes.  Default
-            is '+'.
+            The `matplotlib marker
+            <https://matplotlib.org/stable/api/markers_api.html>`_ to
+            use to mark the center of the boxes.
 
-        markersize: float, optional
-            The marker size in points**2. The default is
+        markersize : float, optional
+            The box center marker size in ``points ** 2``
+            (typographical points are 1/72 inch) . The default is
             ``matplotlib.rcParams['lines.markersize'] ** 2``. If set to
             0, then the box center markers will not be plotted.
 
         color : str, optional
-            The color for the markers and the box outlines.  Default is
-            'blue'.
+            The color for the box center markers and outlines.
 
         alpha : float, optional
             The alpha blending value, between 0 (transparent) and 1
-            (opaque). The blending applies to both the box center
-            markers and the outlines.
+            (opaque), for the box center markers and outlines.
 
         outlines : bool, optional
-            Whether or not to plot the box outlines in addition to the
-            box centers.
+            Whether or not to plot the box outlines.
 
         **kwargs : `dict`
             Any keyword arguments accepted by
-            `matplotlib.patches.Patch`.  Used only if ``outlines`` is
-            True.
+            `matplotlib.patches.Patch`, which is used to draw the box
+            outlines. Used only if ``outlines`` is True.
         """
         import matplotlib.pyplot as plt
 
