@@ -6,6 +6,7 @@ This module defines interpolator classes for Background2D.
 import numpy as np
 
 from photutils.utils import ShepardIDWInterpolator
+from photutils.utils._repr import make_repr
 
 __all__ = ['BkgZoomInterpolator', 'BkgIDWInterpolator']
 
@@ -34,7 +35,7 @@ class BkgZoomInterpolator:
 
     cval : float, optional
         The value used for points outside the boundaries of the input if
-        ``mode='constant'``. Default is 0.0
+        ``mode='constant'``. Default is 0.0.
 
     grid_mode : bool, optional
         If `True` (default), the samples are considered as the centers
@@ -59,6 +60,10 @@ class BkgZoomInterpolator:
         self.grid_mode = grid_mode
         self.clip = clip
 
+    def __repr__(self):
+        params = ('order', 'mode', 'cval', 'grid_mode', 'clip')
+        return make_repr(self, params)
+
     def __call__(self, mesh, bkg2d_obj):
         """
         Resize the 2D mesh array.
@@ -139,6 +144,10 @@ class BkgIDWInterpolator:
         self.power = power
         self.reg = reg
 
+    def __repr__(self):
+        params = ('leafsize', 'n_neighbors', 'power', 'reg')
+        return make_repr(self, params)
+
     def __call__(self, mesh, bkg2d_obj):
         """
         Resize the 2D mesh array.
