@@ -13,7 +13,7 @@ from astropy.utils import lazyproperty
 
 from photutils.detection.core import StarFinderBase, _StarFinderKernel
 from photutils.utils._convolution import _filter_data
-from photutils.utils._misc import _get_version_info
+from photutils.utils._misc import _get_meta
 from photutils.utils.exceptions import NoDetectionsWarning
 
 __all__ = ['DAOStarFinder']
@@ -119,11 +119,15 @@ class DAOStarFinder(StarFinderBase):
             pixel values are negative. Therefore, setting ``peakmax`` to a
             non-positive value would result in exclusion of all objects.
 
-    xycoords : `None` or Nx2 `~numpy.ndarray`
+    xycoords : `None` or Nx2 `~numpy.ndarray`, optional
         The (x, y) pixel coordinates of the approximate centroid
         positions of identified sources. If ``xycoords`` are input, the
         algorithm will skip the source-finding step.
 
+    min_separation : float, optional
+        The minimum separation (in pixels) for detected objects. Note
+        that large values may result in long run times.
+
     See Also
     --------
     IRAFStarFinder
@@ -157,7 +161,8 @@ class DAOStarFinder(StarFinderBase):
     def __init__(self, threshold, fwhm, ratio=1.0, theta=0.0,
                  sigma_radius=1.5, sharplo=0.2, sharphi=1.0, roundlo=-1.0,
                  roundhi=1.0, sky=0.0, exclude_border=False,
-                 brightest=None, peakmax=None, xycoords=None):
+                 brightest=None, peakmax=None, xycoords=None,
+                 min_separation=0.0):
 
         if not np.isscalar(threshold):
             raise TypeError('threshold must be a scalar value.')
@@ -179,6 +184,10 @@ class DAOStarFinder(StarFinderBase):
         self.brightest = self._validate_brightest(brightest)
         self.peakmax = peakmax
 
+        if min_separation < 0:
+            raise ValueError('min_separation must be >= 0')
+        self.min_separation = min_separation
+
         if xycoords is not None:
             xycoords = np.asarray(xycoords)
             if xycoords.ndim != 2 or xycoords.shape[1] != 2:
@@ -208,6 +217,7 @@ class DAOStarFinder(StarFinderBase):
         if self.xycoords is None:
             xypos = self._find_stars(convolved_data, self.kernel,
                                      self.threshold_eff, mask=mask,
+                                     min_separation=self.min_separation,
                                      exclude_border=self.exclude_border)
         else:
             xypos = self.xycoords
@@ -289,7 +299,7 @@ class _DAOStarFinderCatalog:
     convolved_data : 2D `~numpy.ndarray`
         The convolved 2D image.
 
-    xypos: Nx2 `numpy.ndarray`
+    xypos : Nx2 `numpy.ndarray`
         A Nx2 array of (x, y) pixel coordinates denoting the central
         positions of the stars.
 
@@ -305,6 +315,8 @@ class _DAOStarFinderCatalog:
         calculate the source peak value, flux, and magnitude.  The
         default is 0.
 
+    References
+    ----------
     .. _DAOFIND: https://iraf.net/irafhelp.php?val=daofind
     """
 
@@ -691,8 +703,8 @@ class _DAOStarFinderCatalog:
         return cat
 
     def to_table(self, columns=None):
-        meta = {'version': _get_version_info()}
-        table = QTable(meta=meta)
+        table = QTable()
+        table.meta.update(_get_meta())  # keep table.meta type
         if columns is None:
             columns = self.default_columns
         for column in columns:
