@@ -13,7 +13,7 @@ from astropy.utils import lazyproperty
 
 from photutils.detection.core import StarFinderBase, _StarFinderKernel
 from photutils.utils._convolution import _filter_data
-from photutils.utils._misc import _get_version_info
+from photutils.utils._misc import _get_meta
 from photutils.utils._moments import _moments, _moments_central
 from photutils.utils.exceptions import NoDetectionsWarning
 
@@ -39,15 +39,17 @@ class IRAFStarFinder(StarFinderBase):
         The full-width half-maximum (FWHM) of the 2D circular Gaussian
         kernel in units of pixels.
 
-    minsep_fwhm : float, optional
-        The minimum separation for detected objects in units of
-        ``fwhm``.
-
     sigma_radius : float, optional
         The truncation radius of the Gaussian kernel in units of sigma
         (standard deviation) [``1 sigma = FWHM /
         2.0*sqrt(2.0*log(2.0))``].
 
+    minsep_fwhm : float, optional
+        The separation (in units of ``fwhm``) for detected objects. The
+        minimum separation is calculated as ``int((fwhm * minsep_fwhm) +
+        0.5)`` and is clipped to a minimum value of 2. Note that large
+        values may result in long run times.
+
     sharplo : float, optional
         The lower bound on sharpness for object detection.
 
@@ -87,11 +89,21 @@ class IRAFStarFinder(StarFinderBase):
             pixel values are negative. Therefore, setting ``peakmax`` to a
             non-positive value would result in exclusion of all objects.
 
-    xycoords : `None` or Nx2 `~numpy.ndarray`
+    xycoords : `None` or Nx2 `~numpy.ndarray`, optional
         The (x, y) pixel coordinates of the approximate centroid
         positions of identified sources. If ``xycoords`` are input, the
         algorithm will skip the source-finding step.
 
+    min_separation : `None` or float, optional
+        The minimum separation (in pixels) for detected objects. If
+        `None` then ``minsep_fwhm`` will be used, otherwise this keyword
+        overrides ``minsep_fwhm``. Note that large values may result in
+        long run times.
+
+    See Also
+    --------
+    DAOStarFinder
+
     Notes
     -----
     For the convolution step, this routine sets pixels beyond the image
@@ -117,10 +129,6 @@ class IRAFStarFinder(StarFinderBase):
     * `~photutils.detection.IRAFStarFinder` calculates the objects'
       centroid, roundness, and sharpness using image moments.
 
-    See Also
-    --------
-    DAOStarFinder
-
     References
     ----------
     .. [1] https://iraf.net/irafhelp.php?val=starfind
@@ -131,7 +139,7 @@ class IRAFStarFinder(StarFinderBase):
     def __init__(self, threshold, fwhm, sigma_radius=1.5, minsep_fwhm=2.5,
                  sharplo=0.5, sharphi=2.0, roundlo=0.0, roundhi=0.2, sky=None,
                  exclude_border=False, brightest=None, peakmax=None,
-                 xycoords=None):
+                 xycoords=None, min_separation=None):
 
         if not np.isscalar(threshold):
             raise TypeError('threshold must be a scalar value.')
@@ -160,7 +168,14 @@ class IRAFStarFinder(StarFinderBase):
 
         self.kernel = _StarFinderKernel(self.fwhm, ratio=1.0, theta=0.0,
                                         sigma_radius=self.sigma_radius)
-        self.min_separation = max(2, int((self.fwhm * self.minsep_fwhm) + 0.5))
+
+        if min_separation is not None:
+            if min_separation < 0:
+                raise ValueError('min_separation must be >= 0')
+            self.min_separation = min_separation
+        else:
+            self.min_separation = max(2, int((self.fwhm * self.minsep_fwhm)
+                                             + 0.5))
 
     @staticmethod
     def _validate_brightest(brightest):
@@ -262,7 +277,7 @@ class _IRAFStarFinderCatalog:
     convolved_data : 2D `~numpy.ndarray`
         The convolved 2D image.
 
-    xypos: Nx2 `numpy.ndarray`
+    xypos : Nx2 `numpy.ndarray`
         A Nx2 array of (x, y) pixel coordinates denoting the central
         positions of the stars.
 
@@ -472,8 +487,12 @@ class _IRAFStarFinderCatalog:
 
     @lazyproperty
     def roundness(self):
-        return np.sqrt(self.mu_diff**2
-                       + 4.0 * self.moments_central[:, 1, 1]**2) / self.mu_sum
+        # ignore divide-by-zero RuntimeWarning
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore', RuntimeWarning)
+            return (np.sqrt(self.mu_diff**2
+                            + 4.0 * self.moments_central[:, 1, 1]**2)
+                    / self.mu_sum)
 
     @lazyproperty
     def sharpness(self):
@@ -529,8 +548,8 @@ class _IRAFStarFinderCatalog:
         return cat
 
     def to_table(self, columns=None):
-        meta = {'version': _get_version_info()}
-        table = QTable(meta=meta)
+        table = QTable()
+        table.meta.update(_get_meta())  # keep table.meta type
         if columns is None:
             columns = self.default_columns
         for column in columns:
