@@ -13,7 +13,7 @@ from astropy.utils import lazyproperty
 
 from photutils.detection.core import StarFinderBase
 from photutils.utils._convolution import _filter_data
-from photutils.utils._misc import _get_version_info
+from photutils.utils._misc import _get_meta
 from photutils.utils._moments import _moments, _moments_central
 from photutils.utils.exceptions import NoDetectionsWarning
 
@@ -33,7 +33,8 @@ class StarFinder(StarFinderBase):
         A 2D array of the PSF kernel.
 
     min_separation : float, optional
-        The minimum separation for detected objects in pixels.
+        The minimum separation (in pixels) for detected objects. Note
+        that large values may result in long run times.
 
     exclude_border : bool, optional
         Whether to exclude sources found within half the size of the
@@ -54,16 +55,16 @@ class StarFinder(StarFinderBase):
             pixel values are negative. Therefore, setting ``peakmax`` to
             a non-positive value would result in excluding all objects.
 
+    See Also
+    --------
+    DAOStarFinder, IRAFStarFinder
+
     Notes
     -----
     For the convolution step, this routine sets pixels beyond the image
     borders to 0.0.
 
     The source properties are calculated using image moments.
-
-    See Also
-    --------
-    DAOStarFinder, IRAFStarFinder
     """
 
     def __init__(self, threshold, kernel, min_separation=5.0,
@@ -168,11 +169,11 @@ class _StarFinderCatalog:
     data : 2D `~numpy.ndarray`
         The 2D image.
 
-    xypos: Nx2 `numpy.ndarray`
+    xypos : Nx2 `numpy.ndarray`
         A Nx2 array of (x, y) pixel coordinates denoting the central
         positions of the stars.
 
-    shape:  tuple of int
+    shape :  tuple of int
         The shape of the stars cutouts. The shape in both dimensions
         must be odd and match the shape of the smoothing kernel.
     """
@@ -387,8 +388,8 @@ class _StarFinderCatalog:
         return cat
 
     def to_table(self, columns=None):
-        meta = {'version': _get_version_info()}
-        table = QTable(meta=meta)
+        table = QTable()
+        table.meta.update(_get_meta())  # keep table.meta type
         if columns is None:
             columns = self.default_columns
         for column in columns:
