@@ -139,7 +139,7 @@ class EllipseFitter:
         # build the resulting Isophote in cases where iterations run to
         # the maximum allowed (maxit), or the maximum number of flagged
         # data points (fflag) is reached.
-        minimum_amplitude_value = np.Inf
+        minimum_amplitude_value = np.inf
         minimum_amplitude_sample = None
 
         # these must be passed throughout the execution chain.
@@ -162,7 +162,7 @@ class EllipseFitter:
             # This may result in an infinite loop.
             if len(values[2]) < 1:
                 s = str(sample.geometry.sma)
-                log.warning("Too small sample to warrant a fit. SMA is " + s)
+                log.warning('Too small sample to warrant a fit. SMA is ' + s)
                 sample.geometry.fix = fixed_parameters
                 return Isophote(sample, i + 1, False, 3)
 
