@@ -17,7 +17,7 @@ def _least_squares_fit(optimize_func, parameters):
     solution = leastsq(optimize_func, parameters, full_output=True)
 
     if solution[4] > 4:
-        raise RuntimeError("Error in least squares fit: " + solution[3])
+        raise RuntimeError('Error in least squares fit: ' + solution[3])
 
     # return coefficients and covariance matrix
     return (solution[0], solution[1])
