@@ -10,7 +10,7 @@ from astropy.table import QTable
 from photutils.isophote.harmonics import (first_and_second_harmonic_function,
                                           fit_first_and_second_harmonics,
                                           fit_upper_harmonic)
-from photutils.utils._misc import _get_version_info
+from photutils.utils._misc import _get_meta
 
 __all__ = ['Isophote', 'IsophoteList']
 
@@ -304,7 +304,7 @@ class Isophote:
         """
         Compute parameter errors based on the diagonal of the covariance
         matrix of the four harmonic coefficients for harmonics n=1 and
-        n=2.0
+        n=2.0.
         """
         try:
             coeffs, covariance = fit_first_and_second_harmonics(
@@ -760,6 +760,13 @@ class IsophoteList:
         Convert an `~photutils.isophote.IsophoteList` instance to a
         `~astropy.table.QTable` with the main isophote parameters.
 
+        Parameters
+        ----------
+        columns : list of str
+            A list of properties to export from the isophote list. If
+            ``columns`` is 'all' or 'main', it will pick all or few of the
+            main properties.
+
         Returns
         -------
         result : `~astropy.table.QTable`
@@ -812,7 +819,7 @@ def _isophote_list_to_table(isophote_list, columns='main'):
         A list of isophotes.
 
     columns : list of str
-        A list of properties to export from the isophote_list. If
+        A list of properties to export from the ``isophote_list``. If
         ``columns`` is 'all' or 'main', it will pick all or few of the
         main properties.
 
@@ -822,8 +829,8 @@ def _isophote_list_to_table(isophote_list, columns='main'):
         An astropy QTable with the selected or all isophote parameters.
     """
     properties = {}
-    meta = {'version': _get_version_info()}
-    isotable = QTable(meta=meta)
+    isotable = QTable()
+    isotable.meta.update(_get_meta())  # keep isotable.meta type
 
     # main_properties: `List`
     # A list of main parameters matching the original names of
