@@ -4,17 +4,20 @@ Tests for the ellipse module.
 """
 
 import math
+from contextlib import nullcontext
 
 import numpy as np
 import pytest
 from astropy.io import fits
 from astropy.modeling.models import Gaussian2D
+from astropy.utils.exceptions import AstropyUserWarning
 
 from photutils.datasets import get_path, make_noise_image
 from photutils.isophote.ellipse import Ellipse
 from photutils.isophote.geometry import EllipseGeometry
 from photutils.isophote.isophote import Isophote, IsophoteList
 from photutils.isophote.tests.make_test_data import make_test_image
+from photutils.tests.helper import PYTEST_LT_80
 from photutils.utils._optional_deps import HAS_SCIPY
 
 # define an off-center position and a tilted sma
@@ -91,10 +94,23 @@ class TestEllipse:
         # This should result in failure since the real galaxy
         # image is off-center by a large offset.
         ellipse = Ellipse(OFFSET_GALAXY)
-        with pytest.warns(RuntimeWarning, match='Degrees of freedom'):
-            isophote_list = ellipse.fit_image()
 
-        assert len(isophote_list) == 0
+        match1 = 'Degrees of freedom'
+        ctx1 = pytest.warns(RuntimeWarning, match=match1)
+        if PYTEST_LT_80:
+            ctx2 = nullcontext()
+            ctx3 = nullcontext()
+            ctx4 = nullcontext()
+        else:
+            match2 = 'Mean of empty slice'
+            match3 = 'invalid value encountered'
+            match4 = 'No meaningful fit was possible'
+            ctx2 = pytest.warns(RuntimeWarning, match=match2)
+            ctx3 = pytest.warns(RuntimeWarning, match=match3)
+            ctx4 = pytest.warns(AstropyUserWarning, match=match4)
+        with ctx1, ctx2, ctx3, ctx4:
+            isophote_list = ellipse.fit_image()
+            assert len(isophote_list) == 0
 
     def test_offcenter_fit(self):
         # A first guess ellipse that is roughly centered on the
