@@ -4,6 +4,7 @@ Tests for the model module.
 """
 
 import warnings
+from contextlib import nullcontext
 
 import numpy as np
 import pytest
@@ -15,6 +16,7 @@ from photutils.isophote.ellipse import Ellipse
 from photutils.isophote.geometry import EllipseGeometry
 from photutils.isophote.model import build_ellipse_model
 from photutils.isophote.tests.make_test_data import make_test_image
+from photutils.tests.helper import PYTEST_LT_80
 from photutils.utils._optional_deps import HAS_SCIPY
 
 
@@ -73,13 +75,23 @@ def test_model_minimum_radius():
     filepath = get_pkg_data_filename('data/minimum_radius_test.fits')
     with fits.open(filepath) as hdu:
         data = hdu[0].data
-
         g = EllipseGeometry(50.0, 45, 530.0, 0.1, 10.0 / 180.0 * np.pi)
         g.find_center(data)
         ellipse = Ellipse(data, geometry=g)
-        with pytest.warns(RuntimeWarning, match='Degrees of freedom'):
-            isophote_list = ellipse.fit_image(sma0=40, minsma=0, maxsma=350.0,
-                                              step=0.4, nclip=3)
+
+        match1 = 'Degrees of freedom'
+        ctx1 = pytest.warns(RuntimeWarning, match=match1)
+        if PYTEST_LT_80:
+            ctx2 = nullcontext()
+            ctx3 = nullcontext()
+        else:
+            match2 = 'Mean of empty slice'
+            match3 = 'invalid value encountered'
+            ctx2 = pytest.warns(RuntimeWarning, match=match2)
+            ctx3 = pytest.warns(RuntimeWarning, match=match3)
+        with ctx1, ctx2, ctx3:
+            isophote_list = ellipse.fit_image(sma0=40, minsma=0,
+                                              maxsma=350.0, step=0.4, nclip=3)
 
         model = build_ellipse_model(data.shape, isophote_list,
                                     fill=np.mean(data[0:50, 0:50]))
