@@ -7,7 +7,8 @@ import numpy as np
 import pytest
 from numpy.testing import assert_allclose
 
-from photutils.morphology.core import data_properties
+from photutils.datasets import make_wcs
+from photutils.morphology import data_properties
 from photutils.utils._optional_deps import HAS_SKIMAGE
 
 XCS = [25.7]
@@ -35,6 +36,10 @@ def test_data_properties():
     assert props.area.value == 4.0
     assert props2.area.value == 2.0
 
+    wcs = make_wcs(data.shape)
+    props = data_properties(data, mask=None, wcs=wcs)
+    assert props.sky_centroid is not None
+
 
 @pytest.mark.skipif(not HAS_SKIMAGE, reason='skimage is required')
 def test_data_properties_bkg():
