@@ -10,16 +10,19 @@ import os
 import warnings
 from functools import lru_cache
 
+import astropy
 import numpy as np
 from astropy.io import fits, registry
-from astropy.io.fits import HDUList
 from astropy.io.fits.verify import VerifyWarning
 from astropy.modeling import Fittable2DModel, Parameter
 from astropy.nddata import NDData, reshape_as_blocks
+from astropy.utils import minversion
 from astropy.visualization import simple_norm
 
+from photutils.utils._parameters import as_pair
+
 __all__ = ['GriddedPSFModel', 'ModelGridPlotMixin', 'stdpsf_reader',
-           'STDPSFGrid']
+           'webbpsf_reader', 'STDPSFGrid']
 __doctest_skip__ = ['GriddedPSFModelRead', 'STDPSFGrid']
 
 
@@ -75,7 +78,7 @@ class ModelGridPlotMixin:
             'gray_r' colormap for plotting the ePSF difference data
             (``deltas=True``).
 
-        show_dividers : bool, optional
+        dividers : bool, optional
             Whether to show divider lines between the ePSFs.
 
         divider_color, divider_ls : str, optional
@@ -85,6 +88,20 @@ class ModelGridPlotMixin:
 
         figsize : (float, float), optional
             The figure (width, height) in inches.
+
+        Returns
+        -------
+        fig : `matplotlib.figure.Figure`
+            The matplotlib figure object. This will be the current
+            figure if ``ax=None``. Use ``fig.savefig()`` to save the
+            figure to a file.
+
+            Note that when calling this method in a notebook, if you do
+            not store the return value of this function, the figure will
+            be displayed twice due to the REPL automatically displaying
+            the return value of the last function call. Alternatively,
+            you can append a semicolon to the end of the function call
+            to suppress the display of the return value.
         """
         import matplotlib.pyplot as plt
         from matplotlib import cm
@@ -105,8 +122,9 @@ class ModelGridPlotMixin:
         if ax is None:
             if figsize is None and self.meta.get('detector', '') == 'NRCSW':
                 figsize = (20, 8)
-            plt.figure(figsize=figsize)
-            ax = plt.gca()
+            fig, ax = plt.subplots(figsize=figsize)
+        else:
+            fig = plt.gcf()
 
         if peak_norm:  # normalize relative to peak
             if data.max() != 0:
@@ -120,7 +138,10 @@ class ModelGridPlotMixin:
                 vmax_scale = 0.03
             vmax = data.max() * vmax_scale
             vmin = -vmax
-            norm = simple_norm(data, 'linear', min_cut=vmin, max_cut=vmax)
+            if minversion(astropy, '6.1.dev'):
+                norm = simple_norm(data, 'linear', vmin=vmin, vmax=vmax)
+            else:
+                norm = simple_norm(data, 'linear', min_cut=vmin, max_cut=vmax)
         else:
             if cmap is None:
                 cmap = cm.viridis.copy()
@@ -129,8 +150,12 @@ class ModelGridPlotMixin:
                 vmax_scale = 1.0
             vmax = data.max() * vmax_scale
             vmin = vmax / 1.0e4
-            norm = simple_norm(data, 'log', min_cut=vmin, max_cut=vmax,
-                               log_a=1.0e4)
+            if minversion(astropy, '6.1.dev'):
+                norm = simple_norm(data, 'log', vmin=vmin, vmax=vmax,
+                                   log_a=1.0e4)
+            else:
+                norm = simple_norm(data, 'log', min_cut=vmin, max_cut=vmax,
+                                   log_a=1.0e4)
 
         # Set up the coordinate axes to later set tick labels based on
         # detector ePSF coordinates. This sets up axes to have, behind the
@@ -143,8 +168,8 @@ class ModelGridPlotMixin:
         ax.imshow(data, extent=extent, norm=norm, cmap=cmap, origin='lower')
 
         # Use the axes set up above to set appropriate tick labels
-        xticklabels = self._xgrid
-        yticklabels = self._ygrid
+        xticklabels = self._xgrid.astype(int)
+        yticklabels = self._ygrid.astype(int)
         if self.meta.get('detector', '') == 'NRCSW':
             xticklabels = list(xticklabels[0:5]) * 4
             yticklabels = list(yticklabels[0:5]) * 2
@@ -161,15 +186,28 @@ class ModelGridPlotMixin:
             for iy in range(nypsfs):
                 ax.axhline(iy + 0.5, color=divider_color, ls=divider_ls)
 
-        title = (f"{self.meta.get('instrument', '')} "
-                 f"{self.meta.get('detector', '')} "
-                 f"{self.meta.get('filter', '')}")
+        instrument = self.meta.get('instrument', '')
+        if not instrument:
+            # WebbPSF output
+            instrument = self.meta.get('instrume', '')
+        detector = self.meta.get('detector', '')
+        filtername = self.meta.get('filter', '')
+
+        # WebbPSF outputs a tuple with the comment in the second element
+        if isinstance(instrument, (tuple, list, np.ndarray)):
+            instrument = instrument[0]
+        if isinstance(detector, (tuple, list, np.ndarray)):
+            detector = detector[0]
+        if isinstance(filtername, (tuple, list, np.ndarray)):
+            filtername = filtername[0]
+
+        title = f'{instrument} {detector} {filtername}'
         if title != '':
             # add extra space at end
             title += ' '
 
         if deltas:
-            ax.set_title(f'{title}ePSFs – average ePSF')
+            ax.set_title(f'{title}(ePSFs − <ePSF>)')
             if peak_norm:
                 label = 'Difference relative to average ePSF peak'
             else:
@@ -186,7 +224,7 @@ class ModelGridPlotMixin:
             cbar.ax.set_yscale('log')
 
         if self.meta.get('detector', '') == 'NRCSW':
-            # NIRCam NRCSW STDPSF files constain all detectors.
+            # NIRCam NRCSW STDPSF files contain all detectors.
             # The plot gets extra divider lines and SCA name labels.
             nxpsfs = len(self._xgrid)
             nypsfs = len(self._ygrid)
@@ -202,17 +240,21 @@ class ModelGridPlotMixin:
                             det_labels[i][j], color='orange',
                             verticalalignment='top', fontsize=12)
 
+        fig.tight_layout()
+
+        return fig
+
 
 class GriddedPSFModelRead(registry.UnifiedReadWrite):
     """
-    Read and parse a STDPSF FITS file into a `GriddedPSFModel` instance.
+    Read and parse a FITS file into a `GriddedPSFModel` instance.
 
     This class enables the astropy unified I/O layer for
-    `GriddedPSFModel`. This allows easily reading a file in many
+    `GriddedPSFModel`. This allows easily reading a file in different
     supported data formats using syntax such as::
 
       >>> from photutils.psf import GriddedPSFModel
-      >>> psf_model = GriddedPSFModel.read('STDPSF_ACSWFC_F814W.fits')
+      >>> psf_model = GriddedPSFModel.read('filename.fits', format=format)
 
     Get help on the available readers for `GriddedPSFModel` using the
     ``help()`` method::
@@ -223,6 +265,9 @@ class GriddedPSFModelRead(registry.UnifiedReadWrite):
       >>> # Get detailed help on the STSPSF FITS reader
       >>> GriddedPSFModel.read.help('stdpsf')
 
+      >>> # Get detailed help on the WebbPSF FITS reader
+      >>> GriddedPSFModel.read.help('webbpsf')
+
       >>> # Print list of available formats
       >>> GriddedPSFModel.read.list_formats()
 
@@ -239,10 +284,10 @@ class GriddedPSFModelRead(registry.UnifiedReadWrite):
     Returns
     -------
     out : `~photutils.psf.GriddedPSFModel`
-        A gridded ePSF Model corresponding to FITS file contents.
+        A gridded ePSF model corresponding to FITS file contents.
     """
     def __init__(self, instance, cls):
-        super().__init__(instance, cls, "read", registry=None)
+        super().__init__(instance, cls, 'read', registry=None)
         # uses default global registry
 
     def __call__(self, *args, **kwargs):
@@ -257,14 +302,18 @@ class GriddedPSFModel(ModelGridPlotMixin, Fittable2DModel):
     bilinearly interpolated to calculate an ePSF model at an arbitrary
     (x, y) detector position.
 
+    When evaluating this model, it cannot be called with x and y arrays
+    that have greater than 2 dimensions.
+
     Parameters
     ----------
-    data : `~astropy.nddata.NDData`
+    nddata : `~astropy.nddata.NDData`
         A `~astropy.nddata.NDData` object containing the grid of
         reference ePSF arrays. The data attribute must contain a 3D
         `~numpy.ndarray` containing a stack of the 2D ePSFs with a shape
-        of ``(N_psf, ePSF_ny, ePSF_nx)``. The meta attribute must be
-        `dict` containing the following:
+        of ``(N_psf, ePSF_ny, ePSF_nx)``.
+
+        The meta attribute must be `dict` containing the following:
 
             * ``'grid_xypos'``: A list of the (x, y) grid positions of
               each reference ePSF. The order of positions should match the
@@ -272,8 +321,10 @@ class GriddedPSFModel(ModelGridPlotMixin, Fittable2DModel):
               words, ``grid_xypos[i]`` should be the (x, y) position of
               the reference ePSF defined in ``data[i]``.
 
-            * ``'oversampling'``: The integer oversampling factor of the
-              ePSF.
+            * ``'oversampling'``: The integer oversampling factor(s) of
+              the ePSF. If ``oversampling`` is a scalar then it will be
+              used for both axes. If ``oversampling`` has two elements,
+              they must be in ``(y, x)`` order.
 
         The meta attribute may contain other properties such as the
         telescope, instrument, detector, and filter of the ePSF.
@@ -284,6 +335,11 @@ class GriddedPSFModel(ModelGridPlotMixin, Fittable2DModel):
         Class method to create a `GriddedPSFModel` instance from a
         STDPSF FITS file. This method uses :func:`stdpsf_reader` with
         the provided parameters.
+
+    Notes
+    -----
+    Internally, the grid of ePSFs will be arranged and stored such that
+    it is sorted first by y and then by x.
     """
 
     flux = Parameter(description='Intensity scaling factor for the ePSF '
@@ -295,14 +351,17 @@ class GriddedPSFModel(ModelGridPlotMixin, Fittable2DModel):
 
     read = registry.UnifiedReadWriteMethod(GriddedPSFModelRead)
 
-    def __init__(self, data, *, flux=flux.default, x_0=x_0.default,
+    def __init__(self, nddata, *, flux=flux.default, x_0=x_0.default,
                  y_0=y_0.default, fill_value=0.0):
 
-        self._data_input = self._validate_data(data)
-        self.data = data.data
-        self._meta = data.meta  # use _meta to avoid the meta descriptor
-        self.grid_xypos = data.meta['grid_xypos']
-        self.oversampling = data.meta['oversampling']
+        self._validate_data(nddata)
+        self.data, self.grid_xypos = self._define_grid(nddata)
+        # use _meta to avoid the meta descriptor
+        self._meta = nddata.meta.copy()
+        self.oversampling = as_pair('oversampling',
+                                    nddata.meta['oversampling'],
+                                    lower_bound=(0, 1))
+
         self.fill_value = fill_value
 
         self._grid_xpos, self._grid_ypos = np.transpose(self.grid_xypos)
@@ -343,13 +402,34 @@ class GriddedPSFModel(ModelGridPlotMixin, Fittable2DModel):
         if 'oversampling' not in data.meta:
             raise ValueError('"oversampling" must be in the nddata meta '
                              'dictionary.')
-        if not np.isscalar(data.meta['oversampling']):
-            raise ValueError('oversampling must be a scalar value')
 
-        return data
+    def _define_grid(self, nddata):
+        """
+        Sort the input ePSF data into a regular grid where the ePSFs are
+        sorted first by y and then by x.
 
-    def __str__(self):
-        cls_name = f'<{self.__class__.__module__}.{self.__class__.__name__}>'
+        Parameters
+        ----------
+        nddata : `~astropy.nddata.NDData`
+            The input NDData object containing the ePSF data.
+
+        Returns
+        -------
+        data : 3D `~numpy.ndarray`
+            The 3D array of ePSFs.
+        grid_xypos : array of (x, y) pairs
+            The (x, y) positions of the ePSFs, sorted first by y and
+            then by x.
+        """
+        grid_xypos = np.array(nddata.meta['grid_xypos'])
+        # sort by y and then by x
+        idx = np.lexsort((grid_xypos[:, 0], grid_xypos[:, 1]))
+        grid_xypos = grid_xypos[idx]
+        data = nddata.data[idx]
+
+        return data, grid_xypos
+
+    def _cls_info(self):
         cls_info = []
 
         keys = ('STDPSF', 'instrument', 'detector', 'filter', 'grid_shape')
@@ -361,27 +441,37 @@ class GriddedPSFModel(ModelGridPlotMixin, Fittable2DModel):
         cls_info.extend([('Number of ePSFs', len(self.grid_xypos)),
                          ('ePSF shape (oversampled pixels)',
                           self.data.shape[1:]),
-                         ('Oversampling', self.oversampling),
-                         ])
+                         ('Oversampling', tuple(self.oversampling))])
+        return cls_info
 
-        with np.printoptions(threshold=25, edgeitems=5):
-            fmt = [f'{key}: {val}' for key, val in cls_info]
-
-        return f'{cls_name}\n' + '\n'.join(fmt)
-
-    def __repr__(self):
-        return self.__str__()
+    def __str__(self):
+        return self._format_str(keywords=self._cls_info())
 
     def copy(self):
         """
-        Return a copy of this model.
+        Return a copy of this model where only the model parameters are
+        copied.
 
-        Note that the ePSF grid data is not copied. Use the `deepcopy`
-        method if you want to copy the ePSF grid data.
+        All other copied model attributes are references to the
+        original model. This prevents copying the ePSF grid data, which
+        may contain a large array.
+
+        This method is useful if one is interested in only changing
+        the model parameters in a model copy. It is used in the PSF
+        photometry classes during model fitting.
+
+        Use the `deepcopy` method if you want to copy all of the model
+        attributes, including the ePSF grid data.
         """
-        return self.__class__(self._data_input, flux=self.flux.value,
-                              x_0=self.x_0.value, y_0=self.y_0.value,
-                              fill_value=self.fill_value)
+        newcls = object.__new__(self.__class__)
+
+        for key, val in self.__dict__.items():
+            if key in self.param_names:  # copy only the parameter values
+                newcls.__dict__[key] = copy.copy(val)
+            else:
+                newcls.__dict__[key] = val
+
+        return newcls
 
     def deepcopy(self):
         """
@@ -532,7 +622,7 @@ class GriddedPSFModel(ModelGridPlotMixin, Fittable2DModel):
         else:
             # find the four bounding reference ePSFs and interpolate
             ref_indices = self._find_bounding_points(x_0, y_0)
-            xyref = np.array(self.grid_xypos)[ref_indices]
+            xyref = self.grid_xypos[ref_indices]
             psfs = self.data[ref_indices, :, :]
 
             psf_image = self._bilinear_interp(xyref, psfs, x_0, y_0)
@@ -546,6 +636,9 @@ class GriddedPSFModel(ModelGridPlotMixin, Fittable2DModel):
         """
         Evaluate the `GriddedPSFModel` for the input parameters.
         """
+        if x.ndim > 2:
+            raise ValueError('x and y must be 1D or 2D.')
+
         # NOTE: the astropy base Model.__call__() method converts scalar
         # inputs to size-1 arrays before calling evaluate().
         if not np.isscalar(flux):
@@ -562,8 +655,8 @@ class GriddedPSFModel(ModelGridPlotMixin, Fittable2DModel):
 
         # now evaluate the ePSF at the (x_0, y_0) subpixel position on
         # the input (x, y) values
-        xi = self.oversampling * (np.asarray(x, dtype=float) - x_0)
-        yi = self.oversampling * (np.asarray(y, dtype=float) - y_0)
+        xi = self.oversampling[1] * (np.asarray(x, dtype=float) - x_0)
+        yi = self.oversampling[0] * (np.asarray(y, dtype=float) - y_0)
 
         # define origin at the ePSF image center
         ny, nx = self.data.shape[1:]
@@ -589,9 +682,12 @@ def _read_stdpsf(filename):
             header = hdulist[0].header
             data = hdulist[0].data
 
-    npsfs = header['NAXIS3']
-    nxpsfs = header['NXPSFS']
-    nypsfs = header['NYPSFS']
+    try:
+        npsfs = header['NAXIS3']
+        nxpsfs = header['NXPSFS']
+        nypsfs = header['NYPSFS']
+    except KeyError as exc:
+        raise ValueError('Invalid STDPDF FITS file.') from exc
 
     if 'IPSFX01' in header:
         xgrid = [header[f'IPSFX{i:02d}'] for i in range(1, nxpsfs + 1)]
@@ -606,7 +702,7 @@ def _read_stdpsf(filename):
         for ykey in ykeys:
             ygrid.extend([int(n) for n in header[ykey].split()])
     else:
-        raise ValueError('Unknown standard-format ePSF file.')
+        raise ValueError('Unknown STDPSF FITS file.')
 
     # STDPDF FITS positions are 1-indexed
     xgrid = np.array(xgrid) - 1
@@ -788,8 +884,8 @@ def _get_metadata(filename, detector_id):
 
         try:
             inst_det = detector_map[detector]
-        except KeyError:
-            raise ValueError(f'Unknown detector {detector}.')
+        except KeyError as exc:
+            raise ValueError(f'Unknown detector {detector}.') from exc
 
         if inst_det[1] == 'WFPC2':
             wfpc2_map = {1: 'PC', 2: 'WF2', 3: 'WF3', 4: 'WF4'}
@@ -817,8 +913,8 @@ def stdpsf_reader(filename, detector_id=None):
 
     .. note::
         Instead of being used directly, this function is intended to be
-        used as the `GriddedPSFModel` ``read`` method, e.g.,
-        ``model = GriddedPSFModel.read(filename)``.
+        used via the `GriddedPSFModel` ``read`` method, e.g.,
+        ``model = GriddedPSFModel.read(filename, format='stdpsf')``.
 
     STDPSF files are FITS files that contain a 3D array of ePSFs with
     the header detailing where the fiducial ePSFs are located in the
@@ -883,7 +979,7 @@ def stdpsf_reader(filename, detector_id=None):
     # itertools.product iterates over the last input first
     xy_grid = [yx[::-1] for yx in itertools.product(ygrid, xgrid)]
 
-    oversampling = 4
+    oversampling = 4  # assumption for STDPSF files
     nxpsfs = xgrid.shape[0]
     nypsfs = ygrid.shape[0]
     meta = {'grid_xypos': xy_grid,
@@ -900,9 +996,73 @@ def stdpsf_reader(filename, detector_id=None):
     return GriddedPSFModel(NDData(data, meta=meta))
 
 
-def is_fits(origin, filepath, fileobj, *args, **kwargs):
+def webbpsf_reader(filename):
     """
-    Determine whether `origin` is a FITS file.
+    Generate a `~photutils.psf.GriddedPSFModel` from a WebbPSF
+    FITS file containing a PSF grid.
+
+    .. note::
+        Instead of being used directly, this function is intended to be
+        used via the `GriddedPSFModel` ``read`` method, e.g., ``model =
+        GriddedPSFModel.read(filename, format='webbpsf')``.
+
+    The WebbPSF FITS file contain a 3D array of ePSFs with the header
+    detailing where the fiducial ePSFs are located in the detector
+    coordinate frame.
+
+    Parameters
+    ----------
+    filename : str
+        The name of the WebbPSF FITS file. A URL can also be used.
+
+    Returns
+    -------
+    model : `~photutils.psf.GriddedPSFModel`
+        The gridded ePSF model.
+    """
+    with warnings.catch_warnings():
+        warnings.simplefilter('ignore', VerifyWarning)
+        with fits.open(filename, ignore_missing_end=True) as hdulist:
+            header = hdulist[0].header
+            data = hdulist[0].data
+
+    # handle the case of only one 2D PSF
+    data = np.atleast_3d(data)
+
+    if not any('DET_YX' in key for key in header.keys()):
+        raise ValueError('Invalid WebbPSF FITS file; missing "DET_YX{}" '
+                         'header keys.')
+    if 'OVERSAMP' not in header.keys():
+        raise ValueError('Invalid WebbPSF FITS file; missing "OVERSAMP" '
+                         'header key.')
+
+    # convert header to meta dict
+    header = header.copy(strip=True)
+    header.pop('HISTORY', None)
+    header.pop('COMMENT', None)
+    header.pop('', None)
+    meta = dict(header)
+    meta = {key.lower(): meta[key] for key in meta}  # user lower-case keys
+
+    # define grid_xypos from DET_YX{} FITS header keywords
+    xypos = []
+    for key in meta.keys():
+        if 'det_yx' in key:
+            vals = header[key].lstrip('(').rstrip(')').split(',')
+            xypos.append((float(vals[0]), float(vals[1])))
+    meta['grid_xypos'] = xypos
+
+    if 'oversampling' not in meta:
+        meta['oversampling'] = meta['oversamp']
+
+    ndd = NDData(data, meta=meta)
+
+    return GriddedPSFModel(ndd)
+
+
+def is_stdpsf(origin, filepath, fileobj, *args, **kwargs):
+    """
+    Determine whether `origin` is a STDPSF FITS file.
 
     Parameters
     ----------
@@ -911,13 +1071,51 @@ def is_fits(origin, filepath, fileobj, *args, **kwargs):
 
     Returns
     -------
-    is_fits : bool
-        Returns `True` if the given file is a FITS file.
+    is_stdpsf : bool
+        Returns `True` if the given file is a STDPSF FITS file.
     """
     if filepath is not None:
         extens = ('.fits', '.fits.gz', '.fit', '.fit.gz', '.fts', '.fts.gz')
-        return filepath.lower().endswith(extens)
-    return isinstance(args[0], HDUList)
+        isfits = filepath.lower().endswith(extens)
+        if isfits:
+            with warnings.catch_warnings():
+                warnings.simplefilter('ignore', VerifyWarning)
+                header = fits.getheader(filepath)
+            keys = ('NAXIS3', 'NXPSFS', 'NYPSFS')
+            for key in keys:
+                if key not in header:
+                    return False
+            return True
+    return False
+
+
+def is_webbpsf(origin, filepath, fileobj, *args, **kwargs):
+    """
+    Determine whether `origin` is a WebbPSF FITS file.
+
+    Parameters
+    ----------
+    origin : str or readable file-like
+        Path or file object containing a potential FITS file.
+
+    Returns
+    -------
+    is_webbpsf : bool
+        Returns `True` if the given file is a WebbPSF FITS file.
+    """
+    if filepath is not None:
+        extens = ('.fits', '.fits.gz', '.fit', '.fit.gz', '.fts', '.fts.gz')
+        isfits = filepath.lower().endswith(extens)
+        if isfits:
+            with warnings.catch_warnings():
+                warnings.simplefilter('ignore', VerifyWarning)
+                header = fits.getheader(filepath)
+            keys = ('NAXIS3', 'OVERSAMP', 'DET_YX0')
+            for key in keys:
+                if key not in header:
+                    return False
+            return True
+    return False
 
 
 class STDPSFGrid(ModelGridPlotMixin):
@@ -948,9 +1146,10 @@ class STDPSFGrid(ModelGridPlotMixin):
         self._ygrid = grid_data['ygrid']
         xy_grid = [yx[::-1] for yx in itertools.product(self._ygrid,
                                                         self._xgrid)]
-        oversampling = 4
+        oversampling = 4  # assumption for STDPSF files
         self.grid_xypos = xy_grid
-        self.oversampling = oversampling
+        self.oversampling = as_pair('oversampling', oversampling,
+                                    lower_bound=(0, 1))
         meta = {'grid_shape': (len(self._ygrid), len(self._xgrid)),
                 'grid_xypos': xy_grid,
                 'oversampling': oversampling}
@@ -976,8 +1175,7 @@ class STDPSFGrid(ModelGridPlotMixin):
         cls_info.extend([('Number of ePSFs', len(self.grid_xypos)),
                          ('ePSF shape (oversampled pixels)',
                           self.data.shape[1:]),
-                         ('Oversampling', self.oversampling),
-                         ])
+                         ('Oversampling', self.oversampling)])
 
         with np.printoptions(threshold=25, edgeitems=5):
             fmt = [f'{key}: {val}' for key, val in cls_info]
@@ -990,4 +1188,6 @@ class STDPSFGrid(ModelGridPlotMixin):
 
 with registry.delay_doc_updates(GriddedPSFModel):
     registry.register_reader('stdpsf', GriddedPSFModel, stdpsf_reader)
-    registry.register_identifier('stdpsf', GriddedPSFModel, is_fits)
+    registry.register_identifier('stdpsf', GriddedPSFModel, is_stdpsf)
+    registry.register_reader('webbpsf', GriddedPSFModel, webbpsf_reader)
+    registry.register_identifier('webbpsf', GriddedPSFModel, is_webbpsf)
