@@ -20,7 +20,7 @@ from photutils.detection import DAOStarFinder
 from photutils.psf.groupstars import DAOGroup
 from photutils.psf.utils import (_extract_psf_fitting_names,
                                  get_grouped_psf_model, subtract_psf)
-from photutils.utils._misc import _get_version_info
+from photutils.utils._misc import _get_meta
 from photutils.utils._progress_bars import add_progress_bar
 from photutils.utils.exceptions import NoDetectionsWarning
 
@@ -119,7 +119,7 @@ class BasicPSFPhotometry:
     ``init_guesses`` (keyword argument for ``do_photometry``) are both
     not ``None``. In this case, ``finder`` is ignored and initial
     guesses are taken from ``init_guesses``. In addition, an warning is
-    raised to remaind the user about this behavior.
+    raised to remind the user about this behavior.
 
     If there are problems with fitting large groups, change the
     parameters of the grouping algorithm to reduce the number of sources
@@ -452,7 +452,7 @@ class BasicPSFPhotometry:
                 else:
                     star_groups.add_column(col, name=name, copy=True)
 
-        star_groups.meta = {'version': _get_version_info()}
+        star_groups.meta = _get_meta()
 
         return star_groups
 
@@ -509,7 +509,7 @@ class BasicPSFPhotometry:
         unc_tab = QTable()
         for param, isfixed in self.psf_model.fixed.items():
             if not isfixed:
-                unc_tab.add_column(Column(name=param + "_unc"))
+                unc_tab.add_column(Column(name=param + '_unc'))
 
         y, x = np.indices(image.shape)
 
@@ -616,7 +616,7 @@ class BasicPSFPhotometry:
         unc_tab = QTable()
         for param_name in self.psf_model.param_names:
             if not self.psf_model.fixed[param_name]:
-                unc_tab.add_column(Column(name=param_name + "_unc",
+                unc_tab.add_column(Column(name=param_name + '_unc',
                                           data=np.empty(star_group_size)))
 
         k = 0
@@ -819,10 +819,10 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
     @finder.setter
     def finder(self, value):
         if value is None:
-            raise ValueError("finder cannot be None for "
-                             "IterativelySubtractedPSFPhotometry - you may "
-                             "want to use BasicPSFPhotometry. Please see the "
-                             "Detection section on photutils documentation.")
+            raise ValueError('finder cannot be None for '
+                             'IterativelySubtractedPSFPhotometry - you may '
+                             'want to use BasicPSFPhotometry. Please see the '
+                             'Detection section on photutils documentation.')
         self._finder = value
 
     def do_photometry(self, image, *, mask=None, init_guesses=None,
@@ -905,7 +905,7 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
                                                progress_bar=progress_bar,
                                                uncertainty=uncertainty)
 
-        output_table.meta = {'version': _get_version_info()}
+        output_table.meta = _get_meta()
 
         return QTable(output_table)
 
