@@ -7,7 +7,8 @@ import astropy.units as u
 import numpy as np
 import pytest
 from astropy.modeling.fitting import LMLSQFitter, SimplexLSQFitter
-from astropy.nddata import NDData, StdDevUncertainty
+from astropy.modeling.models import Gaussian2D
+from astropy.nddata import NDData, StdDevUncertainty, overlap_slices
 from astropy.table import QTable, Table
 from astropy.utils.exceptions import (AstropyDeprecationWarning,
                                       AstropyUserWarning)
@@ -18,7 +19,7 @@ from photutils.datasets import (make_gaussian_prf_sources_image,
                                 make_noise_image, make_test_psf_data)
 from photutils.detection import DAOStarFinder
 from photutils.psf import (IntegratedGaussianPRF, IterativePSFPhotometry,
-                           PSFPhotometry, SourceGrouper)
+                           PSFPhotometry, SourceGrouper, make_psf_model)
 from photutils.psf.photometry_depr import DAOGroup
 from photutils.utils._optional_deps import HAS_SCIPY
 from photutils.utils.exceptions import NoDetectionsWarning
@@ -28,7 +29,7 @@ from photutils.utils.exceptions import NoDetectionsWarning
 def test_inputs():
     model = IntegratedGaussianPRF(sigma=1.0)
 
-    match = 'psf_model must be an astropy Fittable2DModel'
+    match = 'psf_model must be an Astropy Model subclass'
     with pytest.raises(TypeError, match=match):
         _ = PSFPhotometry(1, 3)
 
@@ -130,7 +131,7 @@ def test_inputs():
 @pytest.fixture(name='test_data')
 def fixture_test_data():
     psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
-    psf_shape = (25, 25)
+    psf_shape = (9, 9)
     nsources = 10
     shape = (101, 101)
     data, true_params = make_test_psf_data(shape, psf_model, psf_shape,
@@ -155,11 +156,18 @@ def test_psf_photometry(test_data):
     phot = psfphot(data, error=error)
     resid_data = psfphot.make_residual_image(data, fit_shape)
 
+    assert isinstance(psfphot.finder_results, QTable)
     assert isinstance(phot, QTable)
     assert len(phot) == len(sources)
     assert isinstance(resid_data, np.ndarray)
     assert resid_data.shape == data.shape
 
+    keys = ('local_bkg', 'init_params', 'fit_infos', 'fit_param_errs',
+            'fit_error_indices', 'npixfit', 'nmodels', 'psfcenter_indices',
+            'fit_residuals')
+    for key in keys:
+        assert key in psfphot.fit_results
+
     unit = u.Jy
     photu = psfphot(data * unit, error=error * unit)
     assert photu['flux_init'].unit == unit
@@ -198,6 +206,94 @@ def test_psf_photometry(test_data):
     assert resid_data3.unit == unit
 
 
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
+def test_model_residual_image(test_data):
+    data, error, _ = test_data
+
+    data = data + 10
+    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    fit_shape = (5, 5)
+    finder = DAOStarFinder(16.0, 2.0)
+    bkgstat = MMMBackground()
+    localbkg_estimator = LocalBackground(5, 10, bkgstat)
+    psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
+                            aperture_radius=4,
+                            localbkg_estimator=localbkg_estimator)
+    psfphot(data, error=error)
+
+    psf_shape = (25, 25)
+    model1 = psfphot.make_model_image(data.shape, psf_shape,
+                                      include_localbkg=False)
+    model2 = psfphot.make_model_image(data.shape, psf_shape,
+                                      include_localbkg=True)
+    resid1 = psfphot.make_residual_image(data, psf_shape,
+                                         include_localbkg=False)
+    resid2 = psfphot.make_residual_image(data, psf_shape,
+                                         include_localbkg=True)
+
+    x, y = 0, 100
+    assert model1[y, x] < 0.1
+    assert model2[y, x] > 9
+    assert resid1[y, x] > 9
+    assert resid2[y, x] < 0
+
+    x, y = 0, 80
+    assert model1[y, x] < 0.1
+    assert model2[y, x] > 18
+    assert resid1[y, x] > 9
+    assert resid2[y, x] < -9
+
+
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
+def test_psf_photometry_compound(test_data):
+    """
+    Test compound models output from ``make_psf_model``.
+    """
+    data, error, sources = test_data
+    x_stddev = y_stddev = 1.8
+    psf_func = Gaussian2D(amplitude=1, x_mean=0, y_mean=0, x_stddev=x_stddev,
+                          y_stddev=y_stddev)
+    psf_model = make_psf_model(psf_func, x_name='x_mean', y_name='y_mean')
+
+    fit_shape = (5, 5)
+    finder = DAOStarFinder(5.0, 3.0)
+
+    psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
+                            aperture_radius=4)
+    phot = psfphot(data, error=error)
+    assert isinstance(phot, QTable)
+    assert len(phot) == len(sources)
+
+    # test results when fit does not converge (fitter_maxiters=10)
+    match = r'One or more fit\(s\) may not have converged.'
+    with pytest.warns(AstropyUserWarning, match=match):
+        psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
+                                aperture_radius=4, fitter_maxiters=10)
+        phot = psfphot(data, error=error)
+        columns1 = ['x_err', 'y_err', 'flux_err']
+        for column in columns1:
+            assert np.all(np.isnan(phot[column]))
+
+    # allow other parameters to vary
+    psf_model.x_stddev_2.fixed = False
+    psf_model.y_stddev_2.fixed = False
+    psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
+                            aperture_radius=4, fitter_maxiters=400)
+    phot = psfphot(data, error=error)
+    columns2 = ['x_stddev_2_init', 'y_stddev_2_init', 'x_stddev_2_fit',
+                'y_stddev_2_fit', 'x_stddev_2_err', 'y_stddev_2_err']
+    for column in columns2:
+        assert column in phot.colnames
+
+    # test results when fit does not converge (fitter_maxiters=10)
+    with pytest.warns(AstropyUserWarning, match=match):
+        psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
+                                aperture_radius=4, fitter_maxiters=10)
+        phot = psfphot(data, error=error)
+        for column in columns1 + ['x_stddev_2_err', 'y_stddev_2_err']:
+            assert np.all(np.isnan(phot[column]))
+
+
 @pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_psf_photometry_mask(test_data):
     data, error, sources = test_data
@@ -334,19 +430,23 @@ def test_psf_photometry_init_params_columns(test_data):
     psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
     fit_shape = (5, 5)
     finder = DAOStarFinder(6.0, 2.0)
-    psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
-                            aperture_radius=4)
+    psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder)
 
     xy_suffixes = ('_init', 'init', 'centroid', '_centroid', '_peak', '',
                    'cen', '_cen', 'pos', '_pos', '_0', '0')
+    flux_cols = ['flux_init', 'flux_0', 'flux0', 'flux', 'source_sum',
+                 'segment_flux', 'kron_flux']
+    flux_cols += flux_cols[0:4]  # pad to have same length as xy_suffixes
+
     xcols = ['x' + i for i in xy_suffixes]
     ycols = ['y' + i for i in xy_suffixes]
 
     phots = []
-    for xcol, ycol in zip(xcols, ycols):
+    for xcol, ycol, fluxcol in zip(xcols, ycols, flux_cols):
         init_params = QTable()
         init_params[xcol] = [42]
         init_params[ycol] = [36]
+        init_params[fluxcol] = [680]
         phot = psfphot(data, error=error, init_params=init_params)
         assert isinstance(phot, QTable)
         assert len(phot) == 1
@@ -371,8 +471,8 @@ def test_grouper(test_data):
     phot = psfphot(data, error=error)
     assert isinstance(phot, QTable)
     assert len(phot) == len(sources)
-    assert_equal(phot['group_id'], (1, 1, 2, 2, 3, 4, 5, 6, 6, 5))
-    assert_equal(phot['group_size'], (2, 2, 2, 2, 1, 1, 2, 2, 2, 2))
+    assert_equal(phot['group_id'], (1, 2, 3, 4, 5, 5, 5, 6, 6, 7))
+    assert_equal(phot['group_size'], (1, 1, 1, 1, 3, 3, 3, 2, 2, 1))
 
 
 @pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
@@ -481,8 +581,8 @@ def test_iterative_psf_photometry(test_data):
     finder = DAOStarFinder(10.0, 2.0)
 
     init_params = QTable()
-    init_params['x'] = [33, 13, 64]
-    init_params['y'] = [12, 15, 22]
+    init_params['x'] = [54, 29, 80]
+    init_params['y'] = [8, 26, 29]
     psfphot = IterativePSFPhotometry(psf_model, fit_shape, finder=finder,
                                      localbkg_estimator=localbkg_estimator,
                                      aperture_radius=4)
@@ -519,6 +619,63 @@ def test_iterative_psf_photometry(test_data):
         assert phot is None
 
 
+def make_psf_model_image(shape, psf_model, param_table, psf_shape):
+    model_params = param_table.colnames
+    data = np.zeros(shape, dtype=float)
+    for row in param_table:
+        for param in model_params:
+            setattr(psf_model, param, row[param])
+        xcen = row['x_0']
+        ycen = row['y_0']
+        slc_lg, _ = overlap_slices(shape, psf_shape, (ycen, xcen), mode='trim')
+        yy, xx = np.mgrid[slc_lg]
+        data[slc_lg] += psf_model(xx, yy)
+    return data
+
+
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
+def test_iterative_psf_photometry_all():
+    sources = QTable()
+    sources['x_0'] = [50, 45, 55, 27, 22, 77, 82]
+    sources['y_0'] = [50, 52, 48, 27, 30, 77, 79]
+    sources['flux'] = [1000, 100, 50, 1000, 100, 1000, 100]
+
+    shape = (101, 101)
+    psf_model = IntegratedGaussianPRF(flux=500, sigma=4.0)
+    psf_shape = (41, 41)
+    data = make_psf_model_image(shape, psf_model, sources, psf_shape)
+
+    fit_shape = (5, 5)
+    finder = DAOStarFinder(0.2, 6.0)
+    sub_shape = psf_shape
+    grouper = SourceGrouper(10)
+    psfphot = IterativePSFPhotometry(psf_model, fit_shape, finder=finder,
+                                     grouper=grouper, aperture_radius=4,
+                                     sub_shape=sub_shape, mode='all',
+                                     maxiters=3)
+    phot = psfphot(data)
+
+    assert len(phot) == 7
+    assert_equal(phot['group_id'], [1, 2, 3, 1, 2, 2, 3])
+    assert_equal(phot['iter_detected'], [1, 1, 1, 2, 2, 2, 2])
+    assert_allclose(phot['flux_fit'], [1000, 1000, 1000, 100, 50, 100, 100])
+
+    resid = psfphot.make_residual_image(data, sub_shape)
+    assert_allclose(resid, 0, atol=1e-6)
+
+    match = 'mode must be "new" or "all".'
+    with pytest.raises(ValueError, match=match):
+        psfphot = IterativePSFPhotometry(psf_model, fit_shape, finder=finder,
+                                         grouper=grouper, aperture_radius=4,
+                                         sub_shape=sub_shape, mode='invalid')
+
+    match = 'grouper must be input for the "all" mode'
+    with pytest.raises(ValueError, match=match):
+        psfphot = IterativePSFPhotometry(psf_model, fit_shape, finder=finder,
+                                         grouper=None, aperture_radius=4,
+                                         sub_shape=sub_shape, mode='all')
+
+
 @pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_iterative_psf_photometry_inputs():
     psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
@@ -591,3 +748,50 @@ def test_out_of_bounds_centroids():
     # out of the bounds of the dataset, producing a
     # masked value in the `cfit` column:
     assert np.any(np.isnan(phot['cfit']))
+
+
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
+def test_make_psf_model():
+    normalize = False
+    sigma = 3.0
+    amplitude = 1.0 / (2 * np.pi * sigma**2)
+    xcen = ycen = 0.0
+    psf0 = Gaussian2D(amplitude, xcen, ycen, sigma, sigma)
+    psf1 = make_psf_model(psf0, x_name='x_mean', y_name='y_mean',
+                          normalize=normalize)
+    psf2 = make_psf_model(psf0, normalize=normalize)
+    psf3 = make_psf_model(psf0, x_name='x_mean', normalize=normalize)
+    psf4 = make_psf_model(psf0, y_name='y_mean', normalize=normalize)
+
+    yy, xx = np.mgrid[0:101, 0:101]
+    psf = psf1.copy()
+    xval = 48
+    yval = 52
+    flux = 14.51
+    psf.x_mean_2 = xval
+    psf.y_mean_2 = yval
+    data = psf(xx, yy) * flux
+
+    fit_shape = 7
+    init_params = Table([[46.1], [57.3], [7.1]],
+                        names=['x_0', 'y_0', 'flux_0'])
+    phot1 = PSFPhotometry(psf1, fit_shape, aperture_radius=None)
+    tbl1 = phot1(data, init_params=init_params)
+
+    phot2 = PSFPhotometry(psf2, fit_shape, aperture_radius=None)
+    tbl2 = phot2(data, init_params=init_params)
+
+    phot3 = PSFPhotometry(psf3, fit_shape, aperture_radius=None)
+    tbl3 = phot3(data, init_params=init_params)
+
+    phot4 = PSFPhotometry(psf4, fit_shape, aperture_radius=None)
+    tbl4 = phot4(data, init_params=init_params)
+
+    assert_allclose((tbl1['x_fit'][0], tbl1['y_fit'][0],
+                     tbl1['flux_fit'][0]), (xval, yval, flux))
+    assert_allclose((tbl2['x_fit'][0], tbl2['y_fit'][0],
+                     tbl2['flux_fit'][0]), (xval, yval, flux))
+    assert_allclose((tbl3['x_fit'][0], tbl3['y_fit'][0],
+                     tbl3['flux_fit'][0]), (xval, yval, flux))
+    assert_allclose((tbl4['x_fit'][0], tbl4['y_fit'][0],
+                     tbl4['flux_fit'][0]), (xval, yval, flux))
