@@ -419,11 +419,55 @@ class SegmentationImage:
         # check if label is in the segmentation array
         bad_labels.update(np.setdiff1d(labels, self.labels))
 
-        if bad_labels:
+        if bad_labels:  # bad_labels is a set
             if len(bad_labels) == 1:
                 raise ValueError(f'label {bad_labels} is invalid')
             raise ValueError(f'labels {bad_labels} are invalid')
 
+    def _make_cmap(self, ncolors, background_color='#000000ff', seed=None):
+        """
+        Define a matplotlib colormap consisting of (random) muted
+        colors.
+
+        This is useful for plotting the segmentation array.
+
+        Parameters
+        ----------
+        ncolors : int
+            The number of the colors in the colormap.
+
+        background_color : Matplotlib color, optional
+            The color of the first color in the colormap.
+            The color may be specified using any of
+            the `Matplotlib color formats
+            <https://matplotlib.org/stable/tutorials/colors/colors.html>`_.
+            This color will be used as the background color (label = 0)
+            when plotting the segmentation image. The default color is
+            black with alpha=1.0 ('#000000ff').
+
+        seed : int, optional
+            A seed to initialize the `numpy.random.BitGenerator`. If
+            `None`, then fresh, unpredictable entropy will be pulled
+            from the OS. Separate function calls with the same ``seed``
+            will generate the same colormap.
+
+        Returns
+        -------
+        cmap : `matplotlib.colors.ListedColormap`
+            The matplotlib colormap with colors in RGBA format.
+        """
+        if self.nlabels == 0:
+            return None
+
+        from matplotlib import colors
+
+        cmap = make_random_cmap(ncolors, seed=seed)
+
+        if background_color is not None:
+            cmap.colors[0] = colors.to_rgba(background_color)
+
+        return cmap
+
     def make_cmap(self, background_color='#000000ff', seed=None):
         """
         Define a matplotlib colormap consisting of (random) muted
@@ -453,17 +497,23 @@ class SegmentationImage:
         cmap : `matplotlib.colors.ListedColormap`
             The matplotlib colormap with colors in RGBA format.
         """
-        if self.nlabels == 0:
-            return None
+        return self._make_cmap(self.max_label + 1,
+                               background_color=background_color,
+                               seed=seed)
 
-        from matplotlib import colors
+    def reset_cmap(self, seed=None):
+        """
+        Reset the colormap (`cmap` attribute) to a new random colormap.
 
-        cmap = make_random_cmap(self.max_label + 1, seed=seed)
-
-        if background_color is not None:
-            cmap.colors[0] = colors.to_rgba(background_color)
-
-        return cmap
+        Parameters
+        ----------
+        seed : int, optional
+            A seed to initialize the `numpy.random.BitGenerator`. If
+            `None`, then fresh, unpredictable entropy will be pulled
+            from the OS. Separate function calls with the same ``seed``
+            will generate the same colormap.
+        """
+        self.cmap = self.make_cmap(background_color='#000000ff', seed=seed)
 
     @lazyproperty
     def cmap(self):
@@ -1063,10 +1113,10 @@ class SegmentationImage:
         Parameters
         ----------
         size : int or tuple of int, optional
-            The size along each axis of the footprint used for the
-            source dilation. If ``size`` is a scalar, then a square
-            footprint of ``size`` will be used. If ``size`` has two
-            elements, they must be in ``(ny, nx)`` order. ``size``
+            The size along each axis of the rectangular footprint used
+            for the source dilation. If ``size`` is a scalar, then a
+            square footprint of ``size`` will be used. If ``size`` has
+            two elements, they must be in ``(ny, nx)`` order. ``size``
             should have odd values for each axis. To perform source
             dilation, either ``size`` or ``footprint`` must be defined.
             If they are both defined, then ``footprint`` overrides
@@ -1147,7 +1197,8 @@ class SegmentationImage:
                 return mask
             else:
                 size = as_pair('size', size, check_odd=False)
-                footprint = np.ones(size)
+                footprint = np.ones(size, dtype=bool)
+        footprint = footprint.astype(bool)
 
         if np.all(footprint):
             # With a rectangular footprint, scipy grey_dilation is
@@ -1157,8 +1208,15 @@ class SegmentationImage:
             from scipy.ndimage import grey_dilation
             return grey_dilation(mask, footprint=footprint)
         else:
-            from scipy.ndimage import binary_dilation
-            return binary_dilation(mask, structure=footprint)
+            # Binary dilation is very slow, especially for large
+            # footprints. The following is a faster implementation
+            # using fast Fourier transforms (FFTs) that gives identical
+            # results to binary_dilation. Based on the following paper:
+            # "Dilation and Erosion of Gray Images with Spherical
+            # Masks", J. Kukal, D. Majerova, A. Prochazka (Jan 2007).
+            # https://www.researchgate.net/publication/238778666_DILATION_AND_EROSION_OF_GRAY_IMAGES_WITH_SPHERICAL_MASKS
+            from scipy.signal import fftconvolve
+            return fftconvolve(mask, footprint, 'same') > 0.5
 
     @lazyproperty
     def _geo_polygons(self):
@@ -1168,11 +1226,15 @@ class SegmentationImage:
         Each item in the list is tuple of (polygon, value) where the
         polygon is a GeoJSON-like dict and the value is the label from
         the segmentation image.
+
+        Note that the coordinates of these polygon vertices are in a
+        reference frame with the (0, 0) origin at the *lower-left*
+        corner of the lower-left pixel.
         """
         from rasterio.features import shapes
 
         polygons = list(shapes(self.data.astype('int32'), connectivity=8))
-        polygons.sort(key=lambda x: x[1])
+        polygons.sort(key=lambda x: x[1])  # sort in label order
 
         # do not include polygons for background (label = 0)
         return polygons[1:]
@@ -1180,17 +1242,22 @@ class SegmentationImage:
     @lazyproperty
     def polygons(self):
         """
-        A list of `Shapely <https://shapely.readthedocs.io/>`_ polygons
-        representing each source segment.
+        A list of `Shapely <https://shapely.readthedocs.io/en/stable/>`_
+        polygons representing each source segment.
         """
+        from shapely import transform
         from shapely.geometry import shape
 
         polygons = []
         for geo_poly in self._geo_polygons:
             polygons.append(shape(geo_poly[0]))
+        # shift the vertices so that the (0, 0) origin is at the
+        # center of the lower-left pixel
+        polygons = transform(polygons, lambda x: x - [0.5, 0.5])
+
         return polygons
 
-    def to_patches(self, *, origin=(0, 0), **kwargs):
+    def to_patches(self, *, origin=(0, 0), scale=1.0, **kwargs):
         """
         Return a list of `~matplotlib.patches.Polygon` objects
         representing each source segment.
@@ -1202,7 +1269,11 @@ class SegmentationImage:
         ----------
         origin : array_like, optional
             The ``(x, y)`` position of the origin of the displayed
-            image.
+            image. This effectively translates the position of the
+            polygons.
+
+        scale : float, optional
+            The scale factor applied to the polygon vertices.
 
         **kwargs : `dict`
             Any keyword arguments accepted by
@@ -1215,14 +1286,16 @@ class SegmentationImage:
         patch_kwargs.update(kwargs)
 
         patches = []
-        for geo_poly in self._geo_polygons:
-            xy = (np.array(geo_poly[0]['coordinates'][0]) - origin
-                  - np.array((0.5, 0.5)))
+        for poly in self.polygons:
+            xy = np.array(poly.exterior.coords)
+            xy = scale * (xy + 0.5) - 0.5
+            xy -= origin
             patches.append(Polygon(xy, **patch_kwargs))
 
         return patches
 
-    def plot_patches(self, *, ax=None, origin=(0, 0), labels=None, **kwargs):
+    def plot_patches(self, *, ax=None, origin=(0, 0), scale=1.0, labels=None,
+                     **kwargs):
         """
         Plot the `~matplotlib.patches.Polygon` objects for the source
         segments on a matplotlib `~matplotlib.axes.Axes` instance.
@@ -1237,8 +1310,11 @@ class SegmentationImage:
             The ``(x, y)`` position of the origin of the displayed
             image.
 
-        labels: int or array of int, optional
-            The label numbers whose polygons are to be ploted. If
+        scale : float, optional
+            The scale factor applied to the polygon vertices.
+
+        labels : int or array of int, optional
+            The label numbers whose polygons are to be plotted. If
             `None`, the polygons for all labels will be plotted.
 
         **kwargs : `dict`
@@ -1275,7 +1351,7 @@ class SegmentationImage:
         if ax is None:
             ax = plt.gca()
 
-        patches = self.to_patches(origin=origin, **kwargs)
+        patches = self.to_patches(origin=origin, scale=scale, **kwargs)
         if labels is not None:
             patches = np.array(patches)
             indices = self.get_indices(labels)
@@ -1297,8 +1373,8 @@ class SegmentationImage:
         Display the segmentation image in a matplotlib
         `~matplotlib.axes.Axes` instance.
 
-        The segmentation image will be displayed with no interpolation
-        and with the origin set to "lower".
+        The segmentation image will be displayed with "nearest"
+        interpolation and with the origin set to "lower".
 
         Parameters
         ----------
@@ -1346,7 +1422,10 @@ class SegmentationImage:
                              [7, 7, 0, 5, 5, 5],
                              [7, 7, 0, 0, 5, 5]])
             segm = SegmentationImage(data)
-            segm.imshow(figsize=(5, 5))
+
+            fig, ax = plt.subplots()
+            im = segm.imshow(ax=ax)
+            fig.colorbar(im, ax=ax)
         """
         import matplotlib.pyplot as plt
 
@@ -1356,7 +1435,122 @@ class SegmentationImage:
             cmap = self.cmap
 
         return ax.imshow(self.data, cmap=cmap, interpolation='nearest',
-                         origin='lower', alpha=alpha)
+                         origin='lower', alpha=alpha, vmin=-0.5,
+                         vmax=self.max_label + 0.5)
+
+    def imshow_map(self, ax=None, figsize=None, dpi=None, cmap=None,
+                   alpha=None, max_labels=25, cbar_labelsize=None):
+        """
+        Display the segmentation image in a matplotlib
+        `~matplotlib.axes.Axes` instance with a colorbar.
+
+        This method is useful for displaying segmentation images that
+        have a small number of labels (e.g., from a cutout) that are
+        not consecutive. It maps the labels to be consecutive integers
+        starting from 1 before plotting. The plotted image values are
+        not the label values, but the colorbar tick labels are used to
+        show the original labels.
+
+        The segmentation image will be displayed with "nearest"
+        interpolation and with the origin set to "lower".
+
+        Parameters
+        ----------
+        ax : `matplotlib.axes.Axes` or `None`, optional
+            The matplotlib axes on which to plot. If `None`, then a new
+            `~matplotlib.axes.Axes` instance will be created.
+
+        figsize : 2-tuple of floats or `None`, optional
+            The figure dimension (width, height) in inches when creating
+            a new Axes. This keyword is ignored if ``axes`` is input.
+
+        dpi : float or `None`, optional
+            The figure dots per inch when creating a new Axes. This
+            keyword is ignored if ``axes`` is input.
+
+        cmap : `matplotlib.colors.Colormap`, str, or `None`, optional
+            The `~matplotlib.colors.Colormap` instance or a registered
+            matplotlib colormap name used to map scalar data to colors.
+            If `None`, then the colormap defined by the `cmap` attribute
+            will be used.
+
+        alpha : float, array_like, or `None`, optional
+            The alpha blending value, between 0 (transparent) and 1
+            (opaque). If alpha is an array, the alpha blending values
+            are applied pixel by pixel, and alpha must have the same
+            shape as the segmentation image.
+
+        max_labels : int, optional
+            The maximum number of labels to display in the colorbar. If
+            the number of labels is greater than ``max_labels``, then
+            the colorbar will not be displayed.
+
+        cbar_labelsize : `None` or float, optional
+            The font size of the colorbar tick labels.
+
+        Returns
+        -------
+        result : `matplotlib.image.AxesImage`
+            An image attached to an `matplotlib.axes.Axes`.
+        cbar_info : tuple or `None`
+            The colorbar information as a tuple containing the
+            `~matplotlib.colorbar.Colorbar` instance, a `~numpy.ndarray`
+            of tick positions, and a `~numpy.ndarray` of tick labels.
+            `None` is returned if the colorbar was not plotted.
+
+        Examples
+        --------
+        .. plot::
+            :include-source:
+
+            import numpy as np
+            from photutils.segmentation import SegmentationImage
+
+            data = np.array([[1, 1, 0, 0, 4, 4],
+                             [0, 0, 0, 0, 0, 4],
+                             [0, 0, 3, 3, 0, 0],
+                             [7, 0, 0, 0, 0, 5],
+                             [7, 7, 0, 5, 5, 5],
+                             [7, 7, 0, 0, 5, 5]])
+            data *= 1000
+            segm = SegmentationImage(data)
+
+            fig, ax = plt.subplots()
+            im, cbar = segm.imshow_map(ax=ax)
+        """
+        import matplotlib.pyplot as plt
+        from matplotlib.colors import ListedColormap
+
+        if ax is None:
+            _, ax = plt.subplots(figsize=figsize, dpi=dpi)
+
+        data, idx = np.unique(self.data, return_inverse=True)
+        idx = idx.reshape(self.data.shape)
+        vmin = -0.5
+        vmax = np.max(idx) + 0.5
+
+        # keep the original cmap colors for the labels
+        if cmap is None:
+            cmap = ListedColormap(self.cmap.colors[data])
+
+        im = ax.imshow(idx, cmap=cmap, interpolation='nearest', origin='lower',
+                       alpha=alpha, vmin=vmin, vmax=vmax)
+
+        cbar_info = None
+        cbar_labels = np.hstack((0, self.labels))
+        if len(cbar_labels) <= max_labels:
+            cbar_ticks = np.arange(len(cbar_labels))
+            cbar = plt.colorbar(im, ax=ax, ticks=cbar_ticks)
+            cbar.ax.set_yticklabels(cbar_labels)
+            if cbar_labelsize is not None:
+                cbar.ax.yaxis.set_tick_params(labelsize=cbar_labelsize)
+            cbar_info = (cbar, cbar_ticks, cbar_labels)
+        else:
+            warnings.warn('The colorbar was not plotted because the number of '
+                          f'labels is greater than {max_labels=}.',
+                          AstropyUserWarning)
+
+        return im, cbar_info
 
 
 class Segment:
@@ -1386,7 +1580,7 @@ class Segment:
 
     polygon : Shapely polygon, optional
         The outline of the segment as a `Shapely
-        <https://shapely.readthedocs.io/>`_ polygon.
+        <https://shapely.readthedocs.io/en/stable/>`_ polygon.
     """
 
     def __init__(self, segment_data, label, slices, bbox, area, *,
