@@ -3,6 +3,8 @@
 Tests for the catalog module.
 """
 
+from io import StringIO
+
 import astropy.units as u
 import numpy as np
 import pytest
@@ -10,7 +12,6 @@ from astropy.convolution import convolve
 from astropy.coordinates import SkyCoord
 from astropy.modeling.models import Gaussian2D
 from astropy.table import QTable
-from astropy.utils.exceptions import AstropyDeprecationWarning
 from numpy.testing import assert_allclose, assert_equal
 
 from photutils.aperture import (BoundingBox, CircularAperture,
@@ -23,7 +24,6 @@ from photutils.segmentation.core import SegmentationImage
 from photutils.segmentation.detect import detect_sources
 from photutils.segmentation.finder import SourceFinder
 from photutils.segmentation.utils import make_2dgaussian_kernel
-from photutils.utils._convolution import _filter_data
 from photutils.utils._optional_deps import (HAS_GWCS, HAS_MATPLOTLIB,
                                             HAS_SCIPY, HAS_SKIMAGE)
 from photutils.utils.cutouts import CutoutImage
@@ -258,6 +258,13 @@ class TestSourceCatalog:
             obj1 = self.cat[0]
             obj2 = obj1[0]
 
+        match = 'is invalid'
+        with pytest.raises(ValueError, match=match):
+            self.cat.get_label(1000)
+
+        with pytest.raises(ValueError, match=match):
+            self.cat.get_labels([1, 2, 1000])
+
     def test_iter(self):
         labels = []
         for obj in self.cat:
@@ -437,24 +444,6 @@ class TestSourceCatalog:
         for line in lines:
             assert line in repr(cat)
 
-    def test_kernel(self):
-        kernel = np.array([[1.0, 2, 1], [2, 4, 2], [1, 2, 100]])
-        kernel /= kernel.sum()
-
-        with pytest.warns(AstropyDeprecationWarning):
-            cat1 = SourceCatalog(self.data, self.segm, kernel=None)
-            cat2 = SourceCatalog(self.data, self.segm, kernel=kernel)
-            assert not np.array_equal(cat1.xcentroid, cat2.xcentroid)
-            assert not np.array_equal(cat1.ycentroid, cat2.ycentroid)
-
-        convolved_data = _filter_data(self.data, kernel, mode='constant',
-                                      fill_value=0.0,
-                                      check_normalization=True)
-        cat3 = SourceCatalog(self.data, self.segm,
-                             convolved_data=convolved_data)
-        assert_allclose(cat2.centroid, cat3.centroid)
-        assert_allclose(cat2.covariance, cat3.covariance)
-
     def test_detection_cat(self):
         data2 = self.data - 5
         cat1 = SourceCatalog(data2, self.segm)
@@ -826,10 +815,19 @@ class TestSourceCatalog:
 
     def test_meta(self):
         meta = self.cat.meta
-        attrs = ('localbkg_width', 'apermask_method', 'kron_params')
+        attrs = ['localbkg_width', 'apermask_method', 'kron_params']
         for attr in attrs:
             assert attr in meta
 
+        tbl = self.cat.to_table()
+        assert tbl.meta == self.cat.meta
+
+        out = StringIO()
+        tbl.write(out, format='ascii.ecsv')
+        tbl2 = QTable.read(out.getvalue(), format='ascii.ecsv')
+        # check order of meta keys
+        assert list(tbl2.meta.keys()) == list(tbl.meta.keys())
+
     def test_semode(self):
         self.cat._set_semode()
         tbl = self.cat.to_table()
