@@ -193,6 +193,13 @@ class TestSegmentationImage:
         with pytest.raises(ValueError):
             _ = segm.bbox
 
+    @pytest.mark.skipif(not HAS_MATPLOTLIB, reason='matplotlib is required')
+    def test_reset_cmap(self):
+        segm = self.segm.copy()
+        cmap = segm.cmap.copy()
+        segm.reset_cmap(seed=123)
+        assert not np.array_equal(cmap.colors, segm.cmap.colors)
+
     @pytest.mark.skipif(not HAS_MATPLOTLIB, reason='matplotlib is required')
     def test_make_cmap(self):
         cmap = self.segm.make_cmap()
@@ -395,6 +402,9 @@ class TestSegmentationImage:
         axim = self.segm.imshow(figsize=(5, 5))
         assert isinstance(axim, AxesImage)
 
+        axim, cbar = self.segm.imshow_map(figsize=(5, 5))
+        assert isinstance(axim, AxesImage)
+
     @pytest.mark.skipif(not HAS_RASTERIO, reason='rasterio is required')
     @pytest.mark.skipif(not HAS_SHAPELY, reason='shapely is required')
     def test_polygons(self):
@@ -404,6 +414,16 @@ class TestSegmentationImage:
         assert len(polygons) == self.segm.nlabels
         assert isinstance(polygons[0], Polygon)
 
+        data = np.zeros((5, 5), dtype=int)
+        data[2, 2] = 10
+        segm = SegmentationImage(data)
+        polygons = segm.polygons
+        assert len(polygons) == 1
+        verts = np.array(polygons[0].exterior.coords)
+        expected_verts = np.array([[1.5, 1.5], [1.5, 2.5], [2.5, 2.5],
+                                   [2.5, 1.5], [1.5, 1.5]])
+        assert_equal(verts, expected_verts)
+
     @pytest.mark.skipif(not HAS_RASTERIO, reason='rasterio is required')
     @pytest.mark.skipif(not HAS_MATPLOTLIB, reason='matplotlib is required')
     def test_patches(self):
@@ -413,6 +433,13 @@ class TestSegmentationImage:
         assert isinstance(patches[0], Polygon)
         assert patches[0].get_edgecolor() == (0, 0, 1, 1)
 
+        scale = 2.0
+        patches2 = self.segm.to_patches(scale=scale)
+        v1 = patches[0].get_verts()
+        v2 = patches2[0].get_verts()
+        v3 = scale * (v1 + 0.5) - 0.5
+        assert_allclose(v2, v3)
+
         patches = self.segm.plot_patches(edgecolor='red')
         assert isinstance(patches[0], Polygon)
         assert patches[0].get_edgecolor() == (1, 0, 0, 1)
