@@ -7,12 +7,9 @@ import astropy.units as u
 import numpy as np
 import pytest
 from astropy.stats import SigmaClip
-from astropy.utils.exceptions import AstropyDeprecationWarning
 from numpy.testing import assert_allclose, assert_array_equal
 
-from photutils.datasets import make_4gaussians_image
-from photutils.segmentation.detect import (detect_sources, detect_threshold,
-                                           make_source_mask)
+from photutils.segmentation.detect import detect_sources, detect_threshold
 from photutils.segmentation.utils import make_2dgaussian_kernel
 from photutils.utils._optional_deps import HAS_SCIPY
 from photutils.utils.exceptions import NoDetectionsWarning
@@ -212,17 +209,6 @@ class TestDetectSources:
         segm = detect_sources(data, threshold=0.9, npixels=1, connectivity=4)
         assert_array_equal(segm.data, ref)
 
-    def test_basic_kernel(self):
-        """Test detection with kernel."""
-        kernel = np.ones((3, 3)) / 9.0
-        threshold = 0.3
-        expected = np.ones((3, 3))
-        expected[2] = 0
-        with pytest.warns(AstropyDeprecationWarning):
-            segm = detect_sources(self.data, threshold, npixels=1,
-                                  kernel=kernel)
-            assert_array_equal(segm.data, expected)
-
     def test_npixels_nonint(self):
         """Test if error raises if npixel is non-integer."""
         with pytest.raises(ValueError):
@@ -238,18 +224,6 @@ class TestDetectSources:
         with pytest.raises(ValueError):
             detect_sources(self.data, threshold=1, npixels=1, connectivity=10)
 
-    def test_kernel_array(self):
-        with pytest.warns(AstropyDeprecationWarning):
-            segm = detect_sources(self.data, 0.1, npixels=1,
-                                  kernel=self.kernel.array)
-            assert_array_equal(segm.data, np.ones((3, 3)))
-
-    def test_kernel(self):
-        with pytest.warns(AstropyDeprecationWarning):
-            segm = detect_sources(self.data, 0.1, npixels=1,
-                                  kernel=self.kernel)
-            assert_array_equal(segm.data, np.ones((3, 3)))
-
     def test_mask(self):
         data = np.zeros((11, 11))
         data[3:8, 3:8] = 5.0
@@ -267,21 +241,3 @@ class TestDetectSources:
     def test_mask_shape(self):
         with pytest.raises(ValueError):
             detect_sources(self.data, 1.0, 1.0, mask=np.ones((5, 5)))
-
-
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
-class TestMakeSourceMask:
-    def setup_class(self):
-        self.data = make_4gaussians_image()
-
-    def test_dilate_size(self):
-        with pytest.warns(AstropyDeprecationWarning):
-            mask1 = make_source_mask(self.data, 5, 10)
-        with pytest.warns(AstropyDeprecationWarning):
-            mask2 = make_source_mask(self.data, 5, 10, dilate_size=20)
-        assert np.count_nonzero(mask2) > np.count_nonzero(mask1)
-
-    def test_no_detections(self):
-        with pytest.warns(AstropyDeprecationWarning):
-            mask = make_source_mask(self.data, 100, 100)
-            assert np.count_nonzero(mask) == 0
