@@ -41,8 +41,8 @@ def _get_date(utc=False):
 
     Parameters
     ----------
-    utz : bool, optional
-        Whether to use the UTZ timezone instead of the local timezone.
+    utc : bool, optional
+        Whether to use the UTC timezone instead of the local timezone.
 
     Returns
     -------
