@@ -1,11 +1,12 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""Checks for optional dependencies using lazy import from
-`PEP 562 <https://www.python.org/dev/peps/pep-0562/>`_.
+"""
+Checks for optional dependencies using lazy import from `PEP 562
+<https://www.python.org/dev/peps/pep-0562/>`_.
 """
 
 import importlib
 
-# This list is a duplicate of the dependencies in setup.cfg "all".
+# This list is a duplicate of the dependencies in pyproject.toml "all".
 # Note that in some cases the package names are different from the
 # pip-install name (e.g.k scikit-image -> skimage).
 optional_deps = ['scipy', 'matplotlib', 'skimage', 'sklearn', 'gwcs',
