@@ -48,7 +48,7 @@ class TestImageDepth:
         if overlap:
             exp_limits = (66.60324687694235, 19.341261496655026)
         else:
-            exp_limits = (67.65345151009167, 19.324275104703975)
+            exp_limits = (68.60472024061636, 19.30911500577945)
 
         data = self.data
         fluxlim = exp_limits[0]
@@ -82,7 +82,7 @@ class TestImageDepth:
         with pytest.raises(ValueError):
             depth(self.data, mask)
 
-        depth = ImageDepth(radius, nsigma=5.0, napers=200, niters=2,
+        depth = ImageDepth(radius, nsigma=5.0, napers=250, niters=2,
                            overlap=False, seed=123, zeropoint=23.9,
                            progress_bar=False)
         mask = np.zeros(self.data.shape)
@@ -136,3 +136,10 @@ class TestImageDepth:
             ImageDepth(12.4, nsigma=5.0, napers=500, niters=2,
                        mask_pad=-7.1, overlap=True, seed=123, zeropoint=23.9,
                        progress_bar=False)
+
+    def test_repr(self):
+        depth = ImageDepth(aper_radius=4, nsigma=5.0, napers=100, niters=2,
+                           overlap=False, seed=123, zeropoint=23.9,
+                           progress_bar=False)
+        cls_repr = repr(depth)
+        assert cls_repr.startswith(f'{depth.__class__.__name__}')
