@@ -4,10 +4,10 @@ Tests for the parameters module.
 """
 
 import numpy as np
-from numpy.testing import assert_equal
 import pytest
+from numpy.testing import assert_equal
 
-from .._parameters import as_pair
+from photutils.utils._parameters import as_pair
 
 
 def test_as_pair():
